@@ -1,4 +1,4 @@
-// $Id: Agent.h,v 1.12 1997/04/25 06:34:17 zeller Exp $
+// $Id: Agent.h,v 1.16 1998/01/27 09:46:31 zeller Exp $
 // Three-Channel Agent Interface 
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_Agent_h
 #define _DDD_Agent_h
@@ -100,7 +100,7 @@
 #include <errno.h>
 #include <string.h>
 
-#ifndef HAVE_STRERROR_DECL
+#if !HAVE_STRERROR_DECL
 extern "C" char *sterror(int errno);
 #endif
 
@@ -166,6 +166,7 @@ private:
 
     Agent *next;	    	// used in agent manager
 
+    Agent& operator = (const Agent&)  { assert(0); return *this; }
 
 protected:
     // call Handlers
