@@ -1,4 +1,4 @@
-// $Id: AgentM.h,v 1.9 1997/04/25 06:34:19 zeller Exp $
+// $Id: AgentM.h,v 1.12 1997/12/15 18:53:24 zeller Exp $
 // Agent Manager
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 // This class is used to perform process-wide actions;
 // especially terminating child agents upon exiting
@@ -42,6 +42,7 @@
 #include "config.h"
 #include "TypeInfo.h"
 #include "bool.h"
+#include "assert.h"
 
 #if !defined(SIGCHLD) && defined(SIGCLD)
 #define SIGCHLD SIGCLD
@@ -65,19 +66,22 @@ private:
     // Remove an agent
     void operator -= (Agent *key);
 
+private:
+    AgentManager(const AgentManager&): 
+	first(0), old_pipe_handler(0), old_chld_handler(0) { assert(0); }
+    AgentManager& operator = (const AgentManager&) { assert(0); return *this; }
+
 public:
     DECLARE_TYPE_INFO
 
     // Constructor
     AgentManager(SignalProc new_chld_handler = SignalProc(SIG_IGN)):
-	first(0)
-    {
+	first(0), 
 	// Ignore "Broken Pipe" signals
-	old_pipe_handler = SignalProc(signal(SIGPIPE, SignalProc(SIG_IGN)));
-
+	old_pipe_handler(SignalProc(signal(SIGPIPE, SignalProc(SIG_IGN)))),
 	// Catch "Death of child" signals
-	old_chld_handler = SignalProc(signal(SIGCHLD, new_chld_handler));
-    }
+	old_chld_handler(SignalProc(signal(SIGCHLD, new_chld_handler)))
+    {}
 
     // Destructor
     virtual ~AgentManager();
