@@ -1,7 +1,7 @@
-// $Id: AppData.h,v 1.34 1997/05/27 15:23:30 zeller Exp $ -*- C++ -*-
+// $Id: AppData.h,v 1.60 1998/01/05 20:27:26 zeller Exp $ -*- C++ -*-
 // DDD application data
 
-// Copyright (C) 1996 Technische Universitaet Braunschweig, Germany.
+// Copyright (C) 1996-1998 Technische Universitaet Braunschweig, Germany.
 // Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 // 
 // This file is part of the DDD Library.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_AppData_h
 #define _DDD_AppData_h
@@ -34,11 +34,17 @@
 #include <X11/Xlib.h>
 
 #include "version.h"
+#include "OnOff.h"
 
 // The DDD application class name
 #define DDD_CLASS_NAME           Ddd_NAME
 
 // For a documentation of these resources, see `Ddd.in'.
+#define XtNsession               "session"
+#define XtNinitialSession        "initialSession"
+#ifndef XtCSessionID
+#define XtCSessionID             "SessionID"
+#endif
 #define XtNdebugger              "debugger"
 #define XtCDebugger              "Debugger"
 #define XtNdebuggerCommand       "debuggerCommand"
@@ -47,35 +53,42 @@
 #define XtNtraceShellCommands    "traceShellCommands"
 #define XtCTrace                 "Trace"
 #define XtNgdbInitCommands       "gdbInitCommands"
-#define XtCGDBInitCommands       "GDBInitCommands"
 #define XtNgdbSettings           "gdbSettings"
-#define XtCGDBSettings           "GDBSettings"
 #define XtNdbxInitCommands       "dbxInitCommands"
-#define XtCDBXInitCommands       "DBXInitCommands"
 #define XtNdbxSettings           "dbxSettings"
-#define XtCDBXSettings           "DBXSettings"
 #define XtNxdbInitCommands       "xdbInitCommands"
-#define XtCXDBInitCommands       "XDBInitCommands"
 #define XtNxdbSettings           "xdbSettings"
-#define XtCXDBSettings           "XDBSettings"
+#define XtNrestartCommands       "restartCommands"
+#define XtCInitCommands          "InitCommands"
+#define XtCSettings              "Settings"
 #define XtNvslPath               "vslPath"
 #define XtCVSLPath               "VSLPath"
 #define XtNvslLibrary            "vslLibrary"
 #define XtCVSLLibrary            "VSLLibrary"
 #define XtNvslDefs               "vslDefs"
 #define XtCVSLDefs               "VSLDefs"
-#define XtNindentAmount          "indentAmount"
-#define XtCIndentAmount          "IndentAmount"
 #define XtNtabWidth              "tabWidth"
 #define XtCTabWidth              "TabWidth"
+#define XtNlinesAboveCursor      "linesAboveCursor"
+#define XtCLinesAboveCursor      "LinesAboveCursor"
+#define XtNlinesBelowCursor      "linesBelowCursor"
+#define XtCLinesBelowCursor      "LinesBelowCursor"
+#define XtNindentSource          "indentSource"
+#define XtNindentCode            "indentCode"
+#define XtCIndent                "Indent"
+#define XtNlineNumberWidth       "lineNumberWidth"
+#define XtCLineNumberWidth       "LineNumberWidth"
+#define XtNlineBufferedConsole   "lineBufferredConsole"
+#define XtCLineBuffered          "LineBuffered"
+#define XtNdisplayShortcuts      "displayShortcuts"
+#define XtCDisplayShortcuts      "DisplayShortcuts"
 #define XtNconsoleButtons        "consoleButtons"
-#define XtCConsoleButtons        "ConsoleButtons"
 #define XtNsourceButtons         "sourceButtons"
-#define XtCSourceButtons         "SourceButtons"
 #define XtNdataButtons           "dataButtons"
-#define XtCDataButtons           "DataButtons"
 #define XtNtoolButtons           "toolButtons"
-#define XtCToolButtons           "ToolButtons"
+#define XtCButtons               "Buttons"
+#define XtNlabelDelimiter        "labelDelimiter"
+#define XtCLabelDelimiter        "LabelDelimiter"
 #define XtNtoolBar               "toolBar"
 #define XtCToolBar               "ToolBar"
 #define XtNseparateDataWindow    "separateDataWindow"
@@ -120,6 +133,10 @@
 #define XtCListCoreCommand       "ListCoreCommand"
 #define XtNlistDirCommand        "listDirCommand"
 #define XtCListDirCommand        "ListDirCommand"
+#define XtNuncompressCommand     "uncompressCommand"
+#define XtCUncompressCommand     "UncompressCommand"
+#define XtNpsCommand             "psCommand"
+#define XtCPsCommand             "PsCommand"
 #define XtNwwwPage               "wwwPage"
 #define XtCWWWPage               "WWWPage"
 #define XtNwwwCommand            "wwwCommand"
@@ -134,6 +151,8 @@
 #define XtCShowManual            "ShowManual"
 #define XtNshowLicense           "showLicense"
 #define XtCShowLicense           "ShowLicense"
+#define XtNshowNews              "showNews"
+#define XtCShowNews              "ShowNews"
 #define XtNcheckConfiguration    "checkConfiguration"
 #define XtCCheckConfiguration    "CheckConfiguration"
 #define XtNprintCommand          "printCommand"
@@ -142,12 +161,18 @@
 #define XtCPaperSize             "PaperSize"
 #define XtNeditCommand           "editCommand"
 #define XtCEditCommand           "EditCommand"
+#define XtNgetCoreCommand        "getCoreCommand"
+#define XtCGetCoreCommand        "GetCoreCommand"
 #define XtNpannedGraphEditor     "pannedGraphEditor"
 #define XtCPannedGraphEditor     "PannedGraphEditor"
 #define XtNfindWordsOnly         "findWordsOnly"
 #define XtCFindWordsOnly         "FindWordsOnly"
+#define XtNfindCaseSensitive     "findCaseSensitive"
+#define XtCFindCaseSensitive     "FindCaseSensitive"
 #define XtNgroupIconify          "groupIconify"
 #define XtCGroupIconify          "GroupIconify"
+#define XtNuniconifyWhenReady    "uniconifyWhenReady"
+#define XtCUniconifyWhenReady    "UniconifyWhenReady"
 #define XtNglobalTabCompletion   "globalTabCompletion"
 #define XtCGlobalTabCompletion   "GlobalTabCompletion"
 #define XtNsaveHistoryOnExit     "saveHistoryOnExit"
@@ -161,10 +186,16 @@
 #define XtNttyMode               "ttyMode"
 #define XtNfullNameMode          "fullNameMode"
 #define XtCTTYMode               "TTYMode"
+#define XtNblockTTYInput         "blockTTYInput"
+#define XtCBlockTTYInput         "BlockTTYInput"
 #define XtNdisplayGlyphs         "displayGlyphs"
 #define XtCDisplayGlyphs         "DisplayGlyphs"
+#define XtNdisplayLineNumbers    "displayLineNumbers"
+#define XtCDisplayLineNumbers    "DisplayLineNumbers"
 #define XtNdisassemble           "disassemble"
 #define XtCDisassemble           "Disassemble"
+#define XtNmaxDisassemble        "maxDisassemble"
+#define XtCMaxDisassemble        "MaxDisassemble"
 #define XtNuseSourcePath         "useSourcePath"
 #define XtCUseSourcePath         "UseSourcePath"
 #define XtNallRegisters          "allRegisters"
@@ -198,41 +229,72 @@
 #define XtCUngrabMousePointer    "UngrabMousePointer"
 #define XtNdetectAliases         "detectAliases"
 #define XtCDetectAliases         "DetectAliases"
+#define XtNalign2dArrays         "align2dArrays"
+#define XtCAlign2dArrays         "Align2dArrays"
+#define XtNbumpDisplays          "bumpDisplays"
+#define XtCBumpDisplays          "BumpDisplays"
+#define XtNhideInactiveDisplays  "hideInactiveDisplays"
+#define XtCHideInactiveDisplays  "HideInactiveDisplays"
 #define XtNstatusHistorySize     "statusHistorySize"
 #define XtCStatusHistorySize     "StatusHistorySize"
 #define XtNverifyButtons         "verifyButtons"
 #define XtCVerifyButtons         "VerifyButtons"
+#define XtNautoRaiseTool         "autoRaiseTool"
+#define XtCAutoRaiseTool         "AutoRaiseTool"
+#define XtNdecorateTool          "decorateTool"
+#define XtCDecorateTool          "DecorateTool"
 #define XtNstickyTool            "stickyTool"
 #define XtCStickyTool            "StickyTool"
 #define XtNtoolRightOffset       "toolRightOffset"
 #define XtNtoolTopOffset         "toolTopOffset"
 #define XtCOffset                "Offset"
-#define XtNlessTifHacks          "lessTifHacks"
-#define XtCLessTifHacks          "LessTifHacks"
+#define XtNautoCommands          "autoCommands"
+#define XtCAutoCommands          "AutoCommands"
+#define XtNautoCommandPrefix     "autoCommandPrefix"
+#define XtCAutoCommandPrefix     "AutoCommandPrefix"
+#define XtNmaxBreakpointNumber   "maxBreakpointNumber"
+#define XtNmaxDisplayNumber      "maxDisplayNumber"
+#define XtCMaxNumber             "MaxNumber"
+#define XtNshowStartupLogo       "showStartupLogo"
+#define XtCShowStartupLogo       "ShowStartupLogo"
+#define XtNcolorIcons            "colorIcons"
+#define XtCColorIcons            "ColorIcons"
+#define XtNlessTifVersion        "lessTifVersion"
+#define XtCLessTifVersion        "LessTifVersion"
 #define XtNdddinitVersion        "dddinitVersion"
 #define XtNappDefaultsVersion    "appDefaultsVersion"
 #define XtCVersion               "Version"
 
 struct AppData {
+    String  session;
+    String  initial_session;
     String  debugger;
     String  debugger_command;
     Boolean trace_dialog;
     Boolean trace_shell_commands;
-    String  gdb_initial_cmds;
+    String  gdb_init_commands;
     String  gdb_settings;
-    String  dbx_initial_cmds;
+    String  dbx_init_commands;
     String  dbx_settings;
-    String  xdb_initial_cmds;
+    String  xdb_init_commands;
     String  xdb_settings;
+    String  restart_commands;
     String  vsl_path;
     String  vsl_library;
     String  vsl_defs;
-    int     indent_amount;
     int     tab_width;
+    int     lines_above_cursor;
+    int     lines_below_cursor;
+    int     indent_source;
+    int     indent_code;
+    int     line_number_width;
+    Boolean line_buffered_console;
+    String  display_shortcuts;
     String  console_buttons;
     String  source_buttons;
     String  data_buttons;
     String  tool_buttons;
+    String  label_delimiter;
     Boolean tool_bar;
     Boolean separate_data_window;
     Boolean separate_source_window;
@@ -255,6 +317,8 @@ struct AppData {
     String  list_source_command;
     String  list_core_command;
     String  list_dir_command;
+    String  uncompress_command;
+    String  ps_command;
     String  www_page;
     String  www_command;
     Boolean show_invocation;
@@ -262,22 +326,29 @@ struct AppData {
     Boolean show_configuration;
     Boolean show_manual;
     Boolean show_license;
+    Boolean show_news;
     Boolean check_configuration;
     String  print_command;
     String  paper_size;
     String  edit_command;
+    String  get_core_command;
     Boolean panned_graph_editor;
     Boolean find_words_only;
+    Boolean find_case_sensitive;
     Boolean group_iconify;
+    Boolean uniconify_when_ready;
     Boolean global_tab_completion;
     Boolean save_history_on_exit;
     Boolean cache_source_files;
     Boolean cache_machine_code;
     Boolean suppress_warnings;
     Boolean tty_mode;
+    OnOff   block_tty_input;
     Boolean full_name_mode;
     Boolean display_glyphs;
+    Boolean display_line_numbers;
     Boolean disassemble;
+    int     max_disassemble;
     Boolean use_source_path;
     Boolean all_registers;
     Boolean button_tips;
@@ -299,12 +370,23 @@ struct AppData {
     int     busy_blink_rate;
     Boolean ungrab_mouse_pointer;
     Boolean detect_aliases;
+    Boolean align_2d_arrays;
+    Boolean bump_displays;
+    Boolean hide_inactive_displays;
     int     status_history_size;
     Boolean verify_buttons;
+    Boolean auto_raise_tool;
+    OnOff   decorate_tool;
     Boolean sticky_tool;
     int     tool_right_offset;
     int     tool_top_offset;
-    Boolean lesstif_hacks;
+    Boolean auto_commands;
+    String  auto_command_prefix;
+    int     max_breakpoint_number;
+    int     max_display_number;
+    String  show_startup_logo;
+    Boolean color_icons;
+    int     lesstif_version;
     String  dddinit_version;
     String  app_defaults_version;
 };
