@@ -1,4 +1,4 @@
-// $Id: ArgField.h,v 1.9 1997/04/25 06:34:30 zeller Exp $
+// $Id: ArgField.h,v 1.12 1997/12/15 18:53:25 zeller Exp $
 // Argument field Implementation
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_ArgField_h
 #define _DDD_ArgField_h
@@ -46,6 +46,7 @@
 #include "HandlerL.h"
 #include "bool.h"
 #include "strclass.h"
+#include "assert.h"
 
 
 //-----------------------------------------------------------------------------
@@ -68,9 +69,14 @@ class ArgField {
 			      XtPointer client_data, 
 			      XtPointer call_data);
 
+private:
+    ArgField(const ArgField&): 
+	arg_text_field(0), handlers(), is_empty(false) { assert(0); }
+    ArgField& operator = (const ArgField&)       { assert(0); return *this; }
+
 public:
     // Constructor
-    ArgField (Widget parent, const char* name);
+    ArgField(Widget parent, const char *name);
 
     bool empty () const { return is_empty; }
 
