@@ -1,4 +1,4 @@
-// $Id: Box.h,v 1.11 1997/04/25 06:34:40 zeller Exp $
+// $Id: Box.h,v 1.14 1997/12/15 18:53:28 zeller Exp $
 // Klasse Box (Deklaration)
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_Box_h
 #define _DDD_Box_h
@@ -115,6 +115,8 @@ private:
 			   const BoxRegion& region, 
 			   const BoxPostScriptGC& gc);
 
+    Box& operator = (const Box&) { assert(0); return *this; }
+
 protected:
     int _links;			// #references (>= 1)
 
@@ -125,7 +127,8 @@ protected:
 
     // Copy constructor
     Box(const Box& box):
-	_size(box._size), _extend(box._extend), _type(box._type), _links(1)
+	_id(), _size(box._size), _extend(box._extend), 
+	_type(box._type), _links(1)
     {}
 	
     // Equality
@@ -144,7 +147,7 @@ public:
     // Constructor
     Box(BoxSize s = BoxSize(0, 0), BoxExtend e = BoxExtend(0, 0), 
 	char *t = "Box"):
-	_size(s), _extend(e), _type(t), _links(1)
+	_id(), _size(s), _extend(e), _type(t), _links(1)
     {}
 
     // Destructor
@@ -244,7 +247,7 @@ public:
 
     // Check for equality
     bool operator == (const Box& b) const;
-    bool operator != (const Box& b) const { return !(operator== (b)); }
+    bool operator != (const Box& b) const { return !(operator == (b)); }
 
     // Check class
     virtual bool isStringBox() const  { return false; }
