@@ -1,4 +1,4 @@
-// $Id: BoxGraphN.h,v 1.8 1997/04/25 06:34:49 zeller Exp $
+// $Id: BoxGraphN.h,v 1.11 1997/12/15 18:53:29 zeller Exp $
 // BoxGraphNode class: RegionGraphNode with box
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_BoxGraphNode_h
 #define _DDD_BoxGraphNode_h
@@ -46,6 +46,11 @@ private:
     Box *_box;		 // the box
     MarkBox *_highlight; // box to be highlighted when selected
 
+    BoxGraphNode& operator = (const BoxGraphNode&)
+    {
+	assert(0); return *this; 
+    }
+
 protected:
     // Draw
     virtual void forceDraw(Widget w, 
