@@ -1,4 +1,4 @@
-// $Id: BoxRegion.h,v 1.8 1997/04/25 06:34:53 zeller Exp $  -*- C++ -*-
+// $Id: BoxRegion.h,v 1.10 1997/12/15 12:59:06 zeller Exp $  -*- C++ -*-
 // BoxRegion class
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_BoxRegion_h
 #define _DDD_BoxRegion_h
@@ -51,15 +51,16 @@ private:
 
 public:
     // Constructors
-    BoxRegion(const BoxPoint& o, const BoxSize& s):
-	_origin(o), _space(s)
+    BoxRegion(const BoxPoint& o, const BoxSize& s)
+	: _origin(o), _space(s)
     {}
 
-    BoxRegion(const BoxPoint& o):
-	_origin(o)
+    BoxRegion(const BoxPoint& o)
+	: _origin(o), _space()
     {}
 
     BoxRegion()
+	: _origin(), _space()
     {}
 
     BoxRegion(const BoxRegion& r):
