@@ -1,4 +1,4 @@
-// $Id: CallNode.h,v 1.7 1997/04/25 06:35:03 zeller Exp $
+// $Id: CallNode.h,v 1.10 1997/12/15 18:53:31 zeller Exp $
 // Deklaration Klasse CallNode
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_CallNode_h
 #define _DDD_CallNode_h
@@ -80,6 +80,12 @@ protected:
 	    *_arg == *(((CallNode *)(&node))->_arg));   // dirty trick
     }
 
+private:
+    CallNode& operator = (const CallNode&)
+    {
+	assert(0); return *this;
+    }
+
 public:
     // Ressourcen
     VSLNode*& arg() { return _arg; }
