@@ -1,4 +1,4 @@
-// $Id: ChunkQueue.h,v 1.8 1997/04/25 06:35:05 zeller Exp $
+// $Id: ChunkQueue.h,v 1.12 1998/01/18 17:33:51 zeller Exp $
 // Chunk buffer
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_ChunkQueue_h
 #define _DDD_ChunkQueue_h
@@ -33,13 +33,12 @@
 #pragma interface
 #endif
 
-
-#include "assert.h"
 #include <stdio.h>
 #include <string.h>
 #include "TypeInfo.h"
+#include "assert.h"
 
-#if defined(HAVE_MEMCPY) && !defined(HAVE_MEMCPY_DECL)
+#if HAVE_MEMCPY && !HAVE_MEMCPY_DECL
 extern "C" void *memcpy(void *to, const void *from, size_t size);
 #endif
 
@@ -68,10 +67,21 @@ private:
 	_data = newData;
     }
 
+    ChunkQueue(const ChunkQueue&)
+	: _length(0), _size(0), _data(0)
+    {
+	assert(0);
+    }
+
+    ChunkQueue& operator = (const ChunkQueue&)
+    {
+	assert(0); return *this;
+    }
+
 public:
     // Constructor
-    ChunkQueue(int initialSize = BUFSIZ):
-	_length(0), _size(initialSize), _data(new char [initialSize])
+    ChunkQueue(int initialSize = BUFSIZ)
+	: _length(0), _size(initialSize), _data(new char [initialSize])
     {}
 
     // Destructor
