@@ -1,4 +1,4 @@
-// $Id: CompositeB.h,v 1.9 1997/04/25 06:35:11 zeller Exp $
+// $Id: CompositeB.h,v 1.12 1997/12/15 18:53:34 zeller Exp $
 // Klasse CompositeBox (Deklaration)
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_CompositeBox_h
 #define _DDD_CompositeBox_h
@@ -53,6 +53,8 @@ private:
     Box **boxes;            // List of children
     void grow();            // Grow the list
 
+    CompositeBox& operator = (const CompositeBox&) { assert(0); return *this; }
+
 protected:
     // Box als Kind hinzufuegen
     virtual void addChild(Box *b)
