@@ -1,4 +1,4 @@
-// $Id: ConstNode.h,v 1.6 1997/04/25 06:35:13 zeller Exp $
+// $Id: ConstNode.h,v 1.9 1997/12/15 18:53:35 zeller Exp $
 // Deklaration Klasse ConstNode
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_ConstNode_h
 #define _DDD_ConstNode_h
@@ -66,14 +66,20 @@ protected:
 		*_box == *(((ConstNode *)&node)->_box); // dirty trick
     }
 
+private:
+    ConstNode& operator = (const ConstNode&)
+    {
+	assert(0); return *this;
+    }
+
 public:
     // ConstNode erzeugen
     ConstNode(Box *box, char *type = "ConstNode"): 
 	VSLNode(type), _box(box)
     {}
 
-    ~ConstNode()
     // ConstNode zerstoeren
+    ~ConstNode()
     {
 	_box->unlink();
     }
@@ -95,6 +101,4 @@ public:
     bool OK() const;
 };
 
-
-
 #endif
