@@ -1,4 +1,4 @@
-// $Id: DataDisp.h,v 1.38 1997/04/29 17:02:06 zeller Exp $
+// $Id: DataDisp.h,v 1.65 1998/01/19 16:07:38 zeller Exp $
 // Data Display
 
 // Copyright (C) 1995-1997 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_DataDisp_h
 #define _DDD_DataDisp_h
@@ -64,19 +64,19 @@
 #include "IntArray.h"
 #include "MString.h"
 #include "DispNode.h"
+#include "string-fun.h"
 
 // DDD includes
 #include "ArgField.h"
 #include "GDBAgent.h"
 #include "GraphEdit.h"
 #include "DispBox.h"
-#include "DispBox.h"
 #include "StringA.h"
 
 
 //-----------------------------------------------------------------------------
-extern GDBAgent* gdb;
-extern ArgField* source_arg;
+extern GDBAgent *gdb;
+extern ArgField *source_arg;
 
 //-----------------------------------------------------------------------------
 class DataDisp {
@@ -87,26 +87,29 @@ class DataDisp {
     static void dispCB                  (Widget, XtPointer, XtPointer);
 
     //-----------------------------------------------------------------------
-    // Button Callbacks
+    // Button callbacks
     //-----------------------------------------------------------------------
     static void dereferenceCB           (Widget, XtPointer, XtPointer);
     static void toggleDetailCB          (Widget, XtPointer, XtPointer);
     static void toggleRotateCB          (Widget, XtPointer, XtPointer);
     static void toggleDisableCB         (Widget, XtPointer, XtPointer);
+    static void rotateCB                (Widget, XtPointer, XtPointer);
+    static void rotateAllCB             (Widget, XtPointer, XtPointer);
     static void newCB                   (Widget, XtPointer, XtPointer);
     static void enableCB                (Widget, XtPointer, XtPointer);
     static void disableCB               (Widget, XtPointer, XtPointer);
     static void showDetailCB            (Widget, XtPointer, XtPointer);
+    static void showMoreDetailCB        (Widget, XtPointer, XtPointer);
     static void hideDetailCB            (Widget, XtPointer, XtPointer);
     static void dependentCB             (Widget, XtPointer, XtPointer);
     static void setCB                   (Widget, XtPointer, XtPointer);
+    static void shortcutCB              (Widget, XtPointer, XtPointer);
 
     //-----------------------------------------------------------------------
     // Popup menu callbacks
     //-----------------------------------------------------------------------
     static void popup_new_argCB         (Widget, XtPointer, XtPointer);
     static void popup_newCB             (Widget, XtPointer, XtPointer);
-    static void dependent_displayDCB    (Widget, XtPointer, XtPointer);
     static void new_displayDCB          (Widget, XtPointer, XtPointer);
     static void setDCB                  (Widget, XtPointer, XtPointer);
 
@@ -117,6 +120,12 @@ class DataDisp {
     static void UpdateDisplayEditorSelectionCB (Widget, XtPointer, XtPointer);
     static void PreLayoutCB                    (Widget, XtPointer, XtPointer);
     static void PostLayoutCB                   (Widget, XtPointer, XtPointer);
+    static void DoubleClickCB                  (Widget, XtPointer, XtPointer);
+
+    //-----------------------------------------------------------------------
+    // Graph callbacks
+    //-----------------------------------------------------------------------
+    static bool bump(RegionGraphNode *node, const BoxSize& newSize);
 
     //-----------------------------------------------------------------------
     // Timers and timer callbacks
@@ -137,7 +146,7 @@ class DataDisp {
     //-----------------------------------------------------------------------
     // Create dialogs
     //-----------------------------------------------------------------------
-    static void new_displayCD (BoxPoint box_point = BoxPoint());
+    static void new_displayCD (Widget w, BoxPoint box_point = BoxPoint());
 
     //-----------------------------------------------------------------------
     // Set sensitivity
@@ -148,7 +157,8 @@ class DataDisp {
     // Helpers
     //-----------------------------------------------------------------------
 
-    static void graph_unselectHP (void*, void*, void*);
+    static bool lose_selection;
+    static void SelectionLostCB(Widget, XtPointer, XtPointer);
 
     static void set_args(BoxPoint p = BoxPoint(),
 			 SelectionMode mode = SetSelection);
@@ -159,14 +169,22 @@ class DataDisp {
     static DispValue *selected_value();
     static DispNode  *selected_node();
 
-    static DispNode  *new_data_node(string& answer);
-    static DispNode  *new_user_node(const string& name, string& answer);
+    static DispNode *new_data_node(const string& name, const string& scope,
+				   const string& answer);
+    static DispNode *new_user_node(const string& name, const string& scope,
+				   const string& answer);
 
-public:
-    static void set_handlers();
+    static int getDispNrAtPoint (BoxPoint point);
+
+    static string numbers(IntArray& a);
+
+    static void show(Widget dialog, int depth, int more);
+
+    static Widget create_display_dialog(Widget parent, String name,
+				      class NewDisplayInfo& info);
+
+    static void toggle_rotate(DispValue *dv, bool all = false);
 
-private:
-    static inline int getDispNrAtPoint (BoxPoint point);
 
     //-----------------------------------------------------------------------
     // Actions
@@ -192,9 +210,22 @@ private:
     //-----------------------------------------------------------------------
     static MMDesc graph_popup[];
     static MMDesc node_popup[];
+    static MMDesc shortcut_popup1[];
+    static MMDesc shortcut_popup2[];
     static MMDesc graph_cmd_area[];
     static MMDesc display_area[];
+    static MMDesc detail_menu[];
+    static MMDesc shortcut_menu[];
+    static MMDesc rotate_menu[];
 
+    static const int DataDisp::shortcut_items;
+
+
+    // Array of shortcut expressions
+    static StringArray shortcut_exprs;
+    static StringArray shortcut_labels;
+
+    static void add_shortcut_expr(const string& expr);
 
 public:
     //-----------------------------------------------------------------------
@@ -202,35 +233,40 @@ public:
     //-----------------------------------------------------------------------
 
     // Create a new display for DISPLAY_EXPRESSION.
+    // SCOPE is the name of the current function (must match backtrace output)
     // If POS is set, the new display is created at this position.
-    // If DEPENDS_ON is set, the new display is made dependent on DEPENDS_ON
+    // If DEPENDS_ON is set, the new display is made dependent on
+    // DEPENDS_ON (a display number or name)
     // If ORIGIN is set, the last origin is set to ORIGIN.
-    static void new_displaySQ       (string display_expression,
-				     BoxPoint *pos = 0,
-				     int depends_on = 0,
-				     Widget origin = 0);
+    static void new_displaySQ(string display_expression,
+			      string scope,
+			      BoxPoint *pos = 0,
+			      string depends_on = "",
+			      Widget origin = 0,
+			      bool verbose = true);
 
     // Refresh displays.  Sends `info display' and `display' to GDB.
-    static void refresh_displaySQ   (Widget origin = 0);
+    static void refresh_displaySQ(Widget origin = 0, bool verbose = true);
 
     // Disable displays given in DISPLAY_NRS.  Sends `disable display' to GDB.
-    static void disable_displaySQ   (IntArray& display_nrs);
+    static void disable_displaySQ(IntArray& display_nrs, bool verbose = true);
 
     // Enable displays given in DISPLAY_NRS.  Sends `enable display' to GDB.
-    static void enable_displaySQ    (IntArray& display_nrs);
+    static void enable_displaySQ(IntArray& display_nrs, bool verbose = true);
 
     // Delete displays given in DISPLAY_NRS.  Sends `delete display' to GDB.
-    static void delete_displaySQ    (IntArray& display_nrs);
+    static void delete_displaySQ(IntArray& display_nrs, bool verbose = true);
 
-    // Same, but via GDB_COMMAND
-    static void new_display       (string display_expression,
-				   BoxPoint *pos = 0,
-				   int depends_on = 0,
-				   Widget origin = 0);
-    static void refresh_display   (Widget origin = 0);
-    static void disable_display   (IntArray& display_nrs);
-    static void enable_display    (IntArray& display_nrs);
-    static void delete_display    (IntArray& display_nrs);
+    // Same, but use the GDB_COMMAND interface for enqueing commands
+    static void new_display(string display_expression,
+			    BoxPoint *pos = 0,
+			    string depends_on = "",
+			    Widget origin = 0);
+
+    static void refresh_display(Widget origin = 0);
+    static void disable_display(IntArray& display_nrs);
+    static void enable_display(IntArray& display_nrs);
+    static void delete_display(IntArray& display_nrs);
 
     // Process 'info display' output in INFO_DISPLAY_ANSWER.  Deletes
     // displays if needed.
@@ -249,6 +285,14 @@ public:
     // Process data output in ANSWERS.
     static void process_addr(StringArray& answers);
 
+    // Set shortcut menu to expressions EXPRS
+    static void set_shortcut_menu(const StringArray& exprs,
+				  const StringArray& labels);
+
+    // Return current shortcut menu items
+    static void get_shortcut_menu(StringArray& exprs,
+				  StringArray& labels);
+
 private:
     // Call me back again
     static void again_new_displaySQ (XtPointer client_data, XtIntervalId *id);
@@ -258,23 +302,22 @@ private:
     static void new_data_display_extraOQC(const string& answer, void* data);
     static void new_data_displaysSQA     (string display_expression, 
 					  void *data);
-    static void new_data_displaysOQAC    (string answers[], 
-					  void*  qu_datas[],
-					  int    count, 
-					  void*  data);
+    static void new_data_displaysOQAC    (const StringArray& answers, 
+					  const VoidArray& qu_datas,
+					  void* data);
 
     static void new_user_displayOQC  (const string& answer, void* data);
 
     static void refresh_displayOQC   (const string& answer, void*  data);
-    static void refresh_displayOQAC  (string answers[],
-				      void*  qu_datas[],
-				      int    count,
+    static void refresh_displayOQAC  (const StringArray& answers,
+				      const VoidArray& qu_datas,
 				      void*  data);
 
     static void disable_displayOQC   (const string& answer, void* data);
     static void enable_displayOQC    (const string& answer, void* data);
     static void delete_displayOQC    (const string& answer, void* data);
 
+    static void add_aliases(IntArray& a);
     static void sort_and_check(IntArray& a);
 
     static void select_with_all_descendants(GraphNode *node);
@@ -290,11 +333,13 @@ private:
     static Delay *delay;
     static Widget last_origin;
     static Time last_select_time;
-    static int next_display_number;
+    static int next_ddd_display_number;
+    static int next_gdb_display_number;
     static bool detect_aliases;
 
     static Widget graph_popup_w;
     static Widget node_popup_w;
+    static Widget shortcut_popup_w;
 
     static Widget edit_displays_dialog_w;
     static Widget display_list_w;
@@ -321,10 +366,32 @@ private:
 
     static Widget graph_form_w;
 
+    static int alias_display_nr(GraphNode *node);
+
+    // State stuff
+    static void write_frame_command(ostream& os, int& current_frame, 
+				   int target_frame);
+    static void write_restore_scope_command(ostream& os,
+					    int& current_frame,
+					    const StringArray& scopes,
+					    DispNode *dn,
+					    bool& ok);
+
+    static bool get_state(ostream& os,
+			  bool restore_state,
+			  bool include_position,
+			  const StringArray& scopes,
+			  int target_frame);
+
+    // Reset done
+    static void reset_done(const string& answer, void *data);
+
 public:
     static Widget graph_edit;
     static Widget graph_cmd_w;
+    static Widget graph_selection_w;
     static ArgField *graph_arg;
+    static bool bump_displays;
 
     // Constructor
     DataDisp (XtAppContext app_context,
@@ -350,6 +417,7 @@ public:
     static void EditDisplaysCB(Widget, XtPointer, XtPointer);
     static void refreshCB(Widget, XtPointer, XtPointer);
     static void selectAllCB(Widget, XtPointer, XtPointer);
+    static void unselectAllCB(Widget, XtPointer, XtPointer);
     static void deleteCB(Widget, XtPointer, XtPointer);
 
     // Helpers for user displays
@@ -363,7 +431,53 @@ public:
 
     // Set whether aliases are to be detected
     static void set_detect_aliases(bool value);
+
+    // True iff we have some selection
+    static bool have_selection();
+
+    // Write current selection as DDD commands to OS
+    // Return true iff all went well
+    static bool get_selection(ostream& os, bool include_position = false);
+
+    // The maximum display number when saving states
+    static int max_display_number;
+
+    // Return DDD commands to restore current state (displays, etc.)
+    // Return true iff all went well.  SCOPES are obtained via
+    // GET_SCOPES (see below).  TARGET_FRAME indicates final frame.
+    static bool get_state(ostream& os, const StringArray& scopes, 
+			  int target_frame = 0);
+    static bool get_scopes(StringArray& scopes);
+
+    // Return true if a core dump is needed to restore displays
+    static bool need_core_to_restore();
+
+    // Return documentation string for shortcut menu item W. 
+    // Returns 0 if W is no shortcut menu item.
+    static MString shortcut_help(Widget w);
+
+    // Reset all
+    static void reset();
 };
 
+inline bool DataDisp::get_selection(ostream& os, bool include_position)
+{
+    StringArray dummy;
+    return get_state(os, false, include_position, dummy, 0);
+}
+
+inline bool DataDisp::get_state(ostream& os, const StringArray& scopes, 
+				int target_frame)
+{
+    return get_state(os, true, true, scopes, target_frame);
+}
+
+inline void DataDisp::get_shortcut_menu(StringArray& exprs,
+					StringArray& labels)
+{
+    exprs  = shortcut_exprs;
+    labels = shortcut_labels;
+}
+
 #endif // _DDD_DataDisp_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
