@@ -1,4 +1,4 @@
-// $Id: DataLength.h,v 1.6 1997/04/25 06:35:21 zeller Exp $
+// $Id: DataLength.h,v 1.9 1997/12/15 18:53:42 zeller Exp $
 // Data/Length struct
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_DataLength_h
 #define _DDD_DataLength_h
@@ -36,6 +36,7 @@
 
 #include <string.h>
 #include "TypeInfo.h"
+#include "assert.h"
 
 struct DataLength {
     DECLARE_TYPE_INFO
@@ -43,13 +44,17 @@ struct DataLength {
     const char *data;
     int length;
 
-    DataLength(const char *d):
-	data(d), length(strlen(d))
+    DataLength(const char *d)
+	: data(d), length(strlen(d))
     {}
 
-    DataLength(const char *d, int l):
-        data(d), length(l)
+    DataLength(const char *d, int l)
+        : data(d), length(l)
     {}
+
+private:
+    DataLength(const DataLength&): data(0), length(0) { assert(0); }
+    DataLength& operator = (const DataLength&) { assert(0); return *this; }
 };
 
 #endif
