@@ -1,4 +1,4 @@
-// $Id: DefCallN.h,v 1.6 1997/04/25 06:35:34 zeller Exp $
+// $Id: DefCallN.h,v 1.9 1997/12/15 18:53:43 zeller Exp $
 // Deklaration Klasse DefCallNode
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_DefCallNode_h
 #define _DDD_DefCallNode_h
@@ -70,6 +70,12 @@ protected:
 		_deflist == ((DefCallNode *)&node)->_deflist); // dirty trick
     }
 
+private:
+    DefCallNode& operator = (const DefCallNode&)
+    {
+	assert(0); return *this;
+    }
+
 public:
     // DefCallNode kopieren
     VSLNode *dup() const
