@@ -1,4 +1,4 @@
-// $Id: Delay.h,v 1.8 1997/04/25 06:35:37 zeller Exp $  -*- C++ -*-
+// $Id: Delay.h,v 1.12 1997/12/15 18:53:44 zeller Exp $  -*- C++ -*-
 // Delay class -- displays an hourglass cursor until destroyed
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_Delay_h
 #define _DDD_Delay_h
@@ -38,7 +38,7 @@
 
 #include "TypeInfo.h"
 #include "VarArray.h"
-
+#include "assert.h"
 
 // _Delay defines a delay for a specific widget only
 class _Delay {
@@ -52,6 +52,9 @@ private:
     static Cursor current_cursor;
     static Cursor hourglass_cache;
 
+    _Delay(const _Delay&): widget(0), old_cursor(0) { assert(0); }
+    _Delay& operator = (const _Delay&) { assert(0); return *this; }
+
 protected:
     static void DestroyCB(Widget, XtPointer, XtPointer);
     virtual Cursor hourglass_cursor();
@@ -80,6 +83,8 @@ public:
     virtual ~Delay();
     static void register_shell(Widget w);
     static const WidgetArray& shells() { return _shells; }
+
+    static void (*shell_registered)(Widget w);
 };
 
 #endif // _DDD_Delay_h
