@@ -1,4 +1,4 @@
-// $Id: DispBox.h,v 1.13 1997/04/25 06:35:43 zeller Exp $
+// $Id: DispBox.h,v 1.18 1997/12/15 18:53:45 zeller Exp $
 // Display boxes
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_DispBox_h
 #define _DDD_DispBox_h
@@ -41,6 +41,7 @@
 #include "Box.h"
 #include "VSLLib.h"
 #include "DispValue.h"
+#include "assert.h"
 
 //-----------------------------------------------------------------------------
 
@@ -48,12 +49,17 @@ class DispBox {
 private:
     Box* mybox;
     Box* title_box;
+
+    DispBox(const DispBox&): mybox(0), title_box(0) { assert(0); }
+    DispBox& operator = (const DispBox&) { assert(0); return *this; }
+
 public:
     // Must be initialized from outside!
     static string  vsllib_name;
     static string  vsllib_path;
     static string  vsllib_defs;
     static int     max_display_title_length;
+    static bool    align_2d_arrays;
 
     // True if the VSL library has been initialized
     static bool    vsllib_initialized;
@@ -62,8 +68,8 @@ public:
     static void init_vsllib(void (*background)() = 0);
 
     // Create a new box; if DV == 0, create a `disabled' box
-    DispBox (string disp_nr,
-	     string name,
+    DispBox (int disp_nr,
+	     const string& name,
 	     const DispValue* dv = 0);
 
     ~DispBox ();
