@@ -1,4 +1,4 @@
-// $Id: DispGraph.h,v 1.14 1997/04/25 06:35:48 zeller Exp $
+// $Id: DispGraph.h,v 1.17 1998/01/05 21:25:26 zeller Exp $
 // Store information about all displayed display expressions
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_DispGraph_h
 #define _DDD_DispGraph_h
@@ -65,10 +65,12 @@ class DispGraph: public Graph {
     bool         no_disabled;
 
 public:
+    static bool hide_inactive_displays;
+
     // Constructor
     DispGraph();
 
-    // loescht alle
+    // Clear all nodes
     void clear();
     
     // Destructor
@@ -102,6 +104,10 @@ public:
     // iff changed.
     bool unalias (int alias_disp_nr);
 
+    // (In)activate display DISP_NR.  Return true iff changed.
+    bool make_active (int disp_nr);
+    bool make_inactive (int disp_nr);
+
     // Determine default positions for NEW_NODE
     BoxPoint default_pos(DispNode *new_node, Widget w, 
 			 int depends_on = 0) const;
@@ -109,9 +115,16 @@ public:
     // Delete DISP_NR; return false if non-existent
     bool del (int disp_nr);
 
-    DispNode* get       (int disp_nr) const { return idMap.get (disp_nr); }
-    int       get_nr    (BoxGraphNode* nodeptr) const;
+    // Return node of display DISP_NR
+    DispNode* get (int disp_nr) const { return idMap.get (disp_nr); }
 
+    // Return number of display NAME
+    int get_by_name(const string& name) const;
+
+    // Return number of node NODEPTR
+    int get_nr(BoxGraphNode *nodeptr) const;
+
+    // Return true iff display has a display numbered DISP_NR
     bool contains (int disp_nr) const { return idMap.contains (disp_nr); }
     
     // Return first/next node; return 0 if non-existent
@@ -122,8 +135,11 @@ public:
     int first_nr (MapRef& ref, Displaying e = Both) const;
     int next_nr  (MapRef& ref, Displaying e = Both) const;
 
+    // Print graph to OS
     void print(ostream& os, const GraphGC& gc = GraphGC()) const
-	{ Graph::print(os, gc); }
+    {
+	Graph::print(os, gc);
+    }
 
 protected:
     BoxPoint adjust_position (DispNode *new_node,
