@@ -1,4 +1,4 @@
-// $Id: DispNode.h,v 1.12 1997/04/25 06:35:51 zeller Exp $
+// $Id: DispNode.h,v 1.20 1998/01/05 20:27:44 zeller Exp $
 // Store information about a single display espression
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_DispNode_h
 #define _DDD_DispNode_h
@@ -68,12 +68,16 @@ string user_command(const string& s);
 // The DispNode class
 //-----------------------------------------------------------------------------
 
-class DispNode {
+class DispNode 
+{
 private:
-    string        mydisp_nr;	      // Display number
+    int           mydisp_nr;	      // Display number
     string        myname;	      // Display expression
     string        myaddr;	      // Location of expression
+    string        myscope;	      // Program location where created
     bool          myenabled;	      // Flag: is display enabled?
+    bool          myactive;	      // Flag: is display active (in scope)?
+    bool          saved_node_hidden;  // Saved `hidden' flag of node
     BoxGraphNode* mynodeptr;	      // Associated graph node 
     DispValue*    disp_value;	      // Associated value
     DispValue*    myselected_value;   // Selected value within DISP_VALUE
@@ -89,26 +93,46 @@ protected:
     static HandlerList handlers;
     static class TagBox *findTagBox(const Box *box, DispValue *dv);
 
+private:
+    DispNode(const DispNode&)
+	: mydisp_nr(0), myname(), myaddr(), myscope(),
+	  myenabled(false), myactive(false), saved_node_hidden(false),
+	  mynodeptr(0), disp_value(0), myselected_value(0), disp_box(0),
+	  mylast_change(0), alias_of(0)
+    {
+	assert(0);
+    }
+    DispNode& operator = (const DispNode&) { assert(0); return *this; }
+
 public:
-    // Constructor
-    DispNode(string& disp_nr, string& name);
-    DispNode(string& disp_nr, string& name, string& value);
+    // Create a new display numbered DISP_NR, named NAME, created at
+    // SCOPE (a function name or "") with a value of VALUE.
+    DispNode(int disp_nr,
+	     const string& name,
+	     const string& scope = "",
+	     const string& value = "");
 
     // Destructor
     ~DispNode();
 
     // Resources
-    const string& disp_nr()  const { return mydisp_nr; }
-    const string& name()     const { return myname; }
-    const string& addr()     const { return myaddr; }
+    int disp_nr()  const        { return mydisp_nr; }
+    const string& name() const  { return myname; }
+    const string& addr() const  { return myaddr; }
+    const string& scope() const { return myscope; }
+
+    bool enabled()  const   { return myenabled; }
+    bool disabled() const   { return !myenabled; }
+    bool active() const     { return myactive; }
 
-    bool enabled()  const { return myenabled; }
-    bool disabled() const { return !myenabled; }
     int last_change() const { return mylast_change; }
 
     bool is_user_command() const { return ::is_user_command(name()); }
     string user_command() const  { return ::user_command(name()); }
 
+    // Return `true' if this expression can be aliased
+    bool alias_ok() const;
+
     BoxGraphNode* nodeptr() const { return mynodeptr; }
     const Box*    box()     const { return mynodeptr->box(); }
     DispValue*    value()   const { return disp_value; }
@@ -143,6 +167,10 @@ public:
     // Disable and enable manually
     void disable();
     void enable();
+
+    // Show and hide manually
+    void make_active();
+    void make_inactive();
 };
 
 #endif // _DDD_DispNode_h
