@@ -1,4 +1,4 @@
-// $Id: DispValue.h,v 1.8 1997/04/25 06:35:55 zeller Exp $
+// $Id: DispValue.h,v 1.19 1998/01/12 19:09:59 zeller Exp $
 // Read and store type and value of a displayed expression
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_DispValue_h
 #define _DDD_DispValue_h
@@ -41,6 +41,7 @@
 #include "bool.h"
 #include "Box.h"
 #include "value-read.h"
+#include "StringSA.h"
 
 //-----------------------------------------------------------------------------
 class DispValue {
@@ -61,36 +62,69 @@ class DispValue {
 				                 // or mytype == Reference
     } v;
 
-    void init(string& value);
+    // Initialize from VALUE.  If TYPE is given, use TYPE as type
+    // instead of inferring it.
+    void init(string& value, DispValueType type = UnknownType);
     void clear();
 
+    DispValue& operator = (const DispValue&)
+    {
+	assert(0); return *this;
+    }
+
+    // Helpers
+    static StringStringAssoc type_cache;
+    static int index_base(const string& expr, int dim);
+    static string add_member_name(const string& base, 
+				  const string& member_name);
+
+protected:
+    // Makes sense only for type() == Array, StructOrClass, BaseClass
+    // Expand/collapse single value
+    void _expand()    { myexpanded = true;  }
+    void _collapse()  { myexpanded = false; }
+
 public:
     // The DispValue type is determined from VALUE
     DispValue (DispValue* parent, 
 	       int        depth,
 	       string&    value,
-	       string     full_name, 
-	       string     print_name);
+	       const string& full_name, 
+	       const string& print_name,
+	       DispValueType type = UnknownType);
 
+    // Copy constructor
+    DispValue (const DispValue& dv);
+
+    // Destructor
     ~DispValue();
 
+    // Duplicator
+    DispValue *dup();
+
     DispValueType type()       const { return mytype; }
     DispValue*    parent()     const { return myparent; }
     int           depth()      const { return mydepth; }
     const string& full_name()  const { return myfull_name; }
     const string& name()       const { return print_name; }
+
+    DispValue*&   parent()     { return myparent; }
+    int&          depth()      { return mydepth; }
+    string&       full_name()  { return myfull_name; }
+    string&       name()       { return print_name; }
+
     bool          is_changed() const { return changed; }
     bool          expanded()   const { return myexpanded; }
     bool          collapsed()  const { return !expanded(); }
 
     // Makes sense only for type() == Simple or Pointer
-    string  value()      const;
+    string value() const;
     
     // Makes sense only for type() == Pointer
-    bool dereferenced()      const;
-    string  dereferenced_name() const;
+    bool dereferenced() const;
+    string dereferenced_name() const;
 
-    int number_of_childs() const;
+    int nchildren() const;
     DispValue* get_child (int i) const;
     
     // Makes sense only for type() == Array
@@ -100,26 +134,42 @@ public:
     // Makes sense only for type() == Pointer
     void dereference();
 
-    // Makes sense only for type() == Array, StructOrClass, BaseClass
-    // Expand/collapse single value
-    void expand()    { myexpanded = true;  }
-    void collapse()  { myexpanded = false; }
+    // Expand/collapse entire tree.  If DEPTH is non-negative, expand
+    // DEPTH levels only.  If DEPTH is negative, expand all.
+    void collapseAll(int depth = -1);
+    void expandAll(int depth = -1);
 
-    // Expand/collapse entire tree
-    void collapseAll();
-    void expandAll();
+    // Custom calls
+    void collapse() { collapseAll(1); }
+    void expand()   { expandAll(1); }
 
     // Count expanded or selected nodes in tree
     int expandedAll()  const;
     int collapsedAll() const;
 
+    // Return height of entire tree
+    int height() const;
+
+    // Return height of expanded tree
+    int heightExpanded() const;
+
     // Makes sense only for type() == Array
     void align_vertical();
     void align_horizontal();
 
-    // True if VALUE was really new (i.e. something changed)
-    void update (string& value, bool& changed, bool& inited);
+    // Update values from VALUE.  Set WAS_CHANGED iff value changed;
+    // Set WAS_INITIALIZED iff type changed.  If TYPE is given, use
+    // TYPE as type instead of inferring it.
+    void update (string& value, bool& changed, bool& inited,
+		 DispValueType type = UnknownType);
     bool new_BaseClass_name (string name);
+
+    // Background processing.  PROCESSED is the number of characters
+    // processed so far.  If this returns true, abort operation.
+    static bool (*background)(int processed);
+
+    // Clear cache of all types read so far
+    static void clear_type_cache();
 };
 
 #endif // _DDD_DispValue_h
