@@ -1,4 +1,4 @@
-/* $Id: DocSpace.c,v 1.5 1997/04/25 06:35:56 zeller Exp $ */
+/* $Id: DocSpace.c,v 1.6 1997/10/03 10:37:34 zeller Exp $ */
 /* DocSpace-Widget (Implementation) */
 
 /*
@@ -25,11 +25,11 @@
     DDD is the data display debugger.
     For details, see the DDD World-Wide-Web page, 
     `http://www.cs.tu-bs.de/softech/ddd/',
-    or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+    or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 */
 
 char DocSpace_rcsid[] = 
-    "$Id: DocSpace.c,v 1.5 1997/04/25 06:35:56 zeller Exp $";
+    "$Id: DocSpace.c,v 1.6 1997/10/03 10:37:34 zeller Exp $";
 
 #include <X11/IntrinsicP.h>
 #include <X11/StringDefs.h>
