@@ -1,4 +1,4 @@
-/* $Id: DocSpaceP.h,v 1.5 1997/04/25 06:35:58 zeller Exp $ */
+/* $Id: DocSpaceP.h,v 1.6 1997/10/03 10:37:35 zeller Exp $ */
 /* DocSpace-Widget (privater Teil Deklaration) */
 
 /*
@@ -25,7 +25,7 @@
     DDD is the data display debugger.
     For details, see the DDD World-Wide-Web page, 
     `http://www.cs.tu-bs.de/softech/ddd/',
-    or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+    or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 */
 
 #ifndef _DocSpaceP_h
