@@ -1,4 +1,4 @@
-// $Id: ExitCB.h,v 1.9 1997/04/25 06:36:06 zeller Exp $
+// $Id: ExitCB.h,v 1.11 1997/10/26 16:29:32 zeller Exp $
 // Exit Callbacks
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_ExitCB_h
 #define _DDD_ExitCB_h
@@ -45,8 +45,11 @@ extern void ExitCB(Widget, XtPointer, XtPointer);
 // Restart program
 extern void RestartCB(Widget, XtPointer, XtPointer);
 
+// Save argv
+extern void register_argv(char *argv[]);
+
 // Save environment
-extern void register_restart(char *argv[]);
+extern void register_environ();
 
 // Return saved environment
 extern char **saved_argv();
