@@ -1,4 +1,4 @@
-// $Id: FontTable.h,v 1.6 1997/04/25 06:36:11 zeller Exp $
+// $Id: FontTable.h,v 1.9 1997/12/15 18:53:48 zeller Exp $
 // Klasse FontTable (Deklaration)
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_FontTable_h
 #define _DDD_FontTable_h
@@ -37,12 +37,21 @@
 #include <X11/Xlib.h>
 #include "strclass.h"
 #include "TypeInfo.h"
+#include "assert.h"
 
 #define MAX_FONTS 511 /* Max #Fonts */
 
 struct FontTableHashEntry {
     XFontStruct *font;
     string name;
+
+    FontTableHashEntry(): font(0), name() {}
+
+private:
+    FontTableHashEntry(const FontTableHashEntry&)
+	: font(0), name() { assert(0); }
+    FontTableHashEntry& operator = (const FontTableHashEntry&)
+	{ assert(0); return *this; }
 };
 
 class FontTable {
@@ -53,6 +62,9 @@ private:
     FontTableHashEntry table[MAX_FONTS];
     Display *_display;
 
+    FontTable(const FontTable&): _display(0) { assert(0); }
+    FontTable& operator = (const FontTable&) { assert(0); return *this; }
+
 public:
     FontTable(Display *display):
 	_display(display)
