@@ -1,4 +1,4 @@
-// $Id: GDBAgent.h,v 1.45 1997/04/25 06:36:14 zeller Exp $
+// $Id: GDBAgent.h,v 1.71 1998/01/23 18:30:32 zeller Exp $
 // Communicate with separate GDB process
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 //-----------------------------------------------------------------------------
 // A GDBAgent creates a connection to an inferior GDB via a TTYAgent.
@@ -50,6 +50,9 @@
 #include "HandlerL.h"
 #include "strclass.h"
 #include "bool.h"
+#include "assert.h"
+#include "StringA.h"
+#include "VoidArray.h"
 
 //-----------------------------------------------------------------------------
 // Debugger types
@@ -91,10 +94,9 @@ typedef void (* OQCProc) (const string& complete_answer,
 			  void*  qu_data);
 
 // Called from send_qu_array with the complete answers
-typedef void (* OQACProc) (string complete_answers[],
-			   void*  qu_datas[],
-			   int    count,
-			   void*  data);
+typedef void (* OQACProc) (const StringArray& complete_answers,
+			   const VoidArray& user_datas,
+			   void *user_data);
 
 //-----------------------------------------------------------------------------
 // Determine debugger type
@@ -112,12 +114,17 @@ const unsigned ReadyForQuestion = TTYAgent_NTypes;
 const unsigned ReadyForCmd      = ReadyForQuestion + 1;
 const unsigned LanguageChanged  = ReadyForCmd + 1;
 const unsigned ReplyRequired    = LanguageChanged + 1;
-const unsigned GDBAgent_NTypes  = ReplyRequired + 1;
+const unsigned EchoDetected     = ReplyRequired + 1;
+const unsigned GDBAgent_NTypes  = EchoDetected + 1;
 
 // Handler info
 struct ReplyRequiredInfo {
     string question;		// Question asked by GDB
     string reply;		// Our reply
+
+    ReplyRequiredInfo()
+	: question(), reply()
+    {}
 };
 
 //-----------------------------------------------------------------------------
@@ -136,35 +143,46 @@ protected:
 	BusyOnQuArray,
 	BusyOnInitialCmds
     };
-    State state;
+    State state;		// Current state
 
 private:
-    DebuggerType    _type;
-    void*           _user_data;
+    DebuggerType    _type;	// Debugger type
+    void*           _user_data;	// used in callbacks etc.
 
-    bool _has_frame_command;	
+    bool _has_frame_command;	// Debugger properties
+    bool _has_func_command;	
     bool _has_run_io_command;
     bool _has_print_r_option;
     bool _has_output_command;
     bool _has_where_h_option;
     bool _has_display_command;
     bool _has_clear_command;
+    bool _has_handler_command;
     bool _has_pwd_command;
     bool _has_setenv_command;
     bool _has_edit_command;
     bool _has_make_command;
+    bool _has_jump_command;
+    bool _has_regs_command;
     bool _has_named_values;
     bool _has_when_command;
     bool _has_when_semicolon;
     bool _has_delete_comma;
     bool _has_err_redirection;
+    bool _has_givenfile_command;
+    bool _has_cont_sig_command;
 
-    ProgramLanguage _program_language;
+    ProgramLanguage _program_language; // Current program language
 
-    bool _trace_dialog;
-    bool _verbatim;
+    bool _trace_dialog;		// True if dialog is to be traced
+    bool _verbatim;		// True if in verbatim mode
+    bool _detect_echos;		// True if echos are to be detected
 
-    string last_prompt;
+    string last_prompt;		// Last prompt received
+    string last_written;	// Last command sent
+    int echoed_characters;      // # of echoed characters so far (-1: no echo)
+
+    GDBAgent& operator = (const GDBAgent&) { assert(0); return *this; }
 
 protected:
     // Return PREFIX + EXPR, parenthesizing EXPR if needed
@@ -173,6 +191,9 @@ protected:
     // Return EXPR + SUFFIX, parenthesizing EXPR if needed
     static string append_suffix(const string& expr, const string& suffix);
 
+    // General trace function
+    void trace(char *prefix, void *call_data) const;
+
 public:
     // Constructor
     GDBAgent (XtAppContext app_context,
@@ -186,6 +207,7 @@ public:
 
     ~GDBAgent ();
 
+    // Start new process
     void do_start (OAProc  on_answer,
 		   OACProc on_answer_completion,
 		   void*   user_data);
@@ -195,8 +217,8 @@ public:
     void start_plus (OAProc   on_answer,
 		     OACProc  on_answer_completion,
 		     void*    user_data,
-		     string   cmds [],
-		     void*    qu_datas [],
+		     const StringArray& cmds,
+		     const VoidArray& user_datas,
 		     int      qu_count,
 		     OQACProc on_qu_array_completion,
 		     void*    qa_data);
@@ -215,19 +237,20 @@ public:
     // 3. Send CMDS, as in send_qu_array.
     // 4. When all replies have come in: call OACProc and OQACProc.
     //
-    bool send_user_cmd_plus (string   cmds [],
-			     void*    qu_datas [],
+    bool send_user_cmd_plus (const StringArray& cmds,
+			     const VoidArray& qu_datas,
 			     int      qu_count,
 			     OQACProc on_qu_array_completion,
 			     void*    qa_data,
-			     string user_cmd, void* user_data = 0);
+			     string user_cmd,
+			     void* user_data = 0);
 
     bool send_question (string  cmd,
 			OQCProc on_question_completion,
 			void*   qu_data);
 
-    bool send_qu_array (string   cmds [],
-			void*    qu_datas [],
+    bool send_qu_array (const StringArray& cmds,
+			const VoidArray& qu_datas,
 			int      qu_count,
 			OQACProc on_qu_array_completion,
 			void*    qa_data);
@@ -249,6 +272,10 @@ public:
     bool has_frame_command() const    { return _has_frame_command; }	
     bool has_frame_command(bool val)  { return _has_frame_command = val; }
 
+    // True if debugger has `func' command
+    bool has_func_command() const    { return _has_func_command; }	
+    bool has_func_command(bool val)  { return _has_func_command = val; }
+
     // True if debugger has `run_io' command
     bool has_run_io_command() const    { return _has_run_io_command; }
     bool has_run_io_command(bool val)  { return _has_run_io_command = val; }
@@ -273,6 +300,10 @@ public:
     bool has_clear_command() const     { return _has_clear_command; }
     bool has_clear_command(bool val)   { return _has_clear_command = val; }
 
+    // True if debugger has `handler' command
+    bool has_handler_command() const   { return _has_handler_command; }
+    bool has_handler_command(bool val) { return _has_handler_command = val; }
+
     // True if debugger has `pwd' command
     bool has_pwd_command() const       { return _has_pwd_command; }
     bool has_pwd_command(bool val)     { return _has_pwd_command = val; }
@@ -289,6 +320,14 @@ public:
     bool has_make_command() const      { return _has_make_command; }
     bool has_make_command(bool val)    { return _has_make_command = val; }
 
+    // True if debugger has `jump' command
+    bool has_jump_command() const      { return _has_jump_command; }
+    bool has_jump_command(bool val)    { return _has_jump_command = val; }
+
+    // True if debugger has `regs' command
+    bool has_regs_command() const      { return _has_regs_command; }
+    bool has_regs_command(bool val)    { return _has_regs_command = val; }
+
     // True if debugger issues `NAME = VALUE' upon `print' commands
     bool has_named_values() const      { return _has_named_values; }
     bool has_named_values(bool val)    { return _has_named_values = val; }
@@ -309,6 +348,17 @@ public:
     bool has_err_redirection() const   { return _has_err_redirection; }
     bool has_err_redirection(bool val) { return _has_err_redirection = val; }
 
+    // True if debugger has `givenfile' command
+    bool has_givenfile_command() const   { return _has_givenfile_command; }
+    bool has_givenfile_command(bool val) 
+    {
+	return _has_givenfile_command = val;
+    }
+
+    // True if debugger has `cont sig' command
+    bool has_cont_sig_command() const   { return _has_cont_sig_command; }
+    bool has_cont_sig_command(bool val) { return _has_cont_sig_command = val; }
+
     // Current program language
     ProgramLanguage program_language() const   { return _program_language; }
     ProgramLanguage program_language(ProgramLanguage val) 
@@ -322,6 +372,28 @@ public:
     }
     ProgramLanguage program_language(string text);
 
+    // True if debugger can enable breakpoints
+    bool has_enable_command() const
+    { 
+	return type() == GDB || type() == XDB || has_handler_command();
+    }
+    bool has_disable_command() const
+    {
+	return has_enable_command();
+    }
+
+    // True if debugger can set ignore counts on breakpoints
+    bool has_ignore_command() const
+    {
+	return type() == GDB || type() == XDB || has_handler_command();
+    }
+
+    // True if debugger can set conditions on breakpoints
+    bool has_condition_command() const
+    {
+	return type() == GDB;
+    }
+
     // True if debugger dialog is traced on clog
     bool trace_dialog() const    { return _trace_dialog; }
     bool trace_dialog(bool val);
@@ -330,6 +402,10 @@ public:
     bool verbatim() const        { return _verbatim; }
     bool verbatim(bool val)      { return _verbatim = val; }
 
+    // True if checking for echos
+    bool detect_echos() const        { return _detect_echos; }
+    bool detect_echos(bool val)      { return _detect_echos = val; }
+
     // GDB: "print EXPR".  If INTERNAL is set, avoid side effects
     // (such as setting the value history in GDB).
     string print_command(string expr = "", bool internal = true) const; 
@@ -337,27 +413,66 @@ public:
     string assign_command(string var, string expr) const;
 
     string display_command(string expr = "") const; // GDB: "display EXPR"
-    string where_command() const;	            // GDB: "where "
+    string where_command(int count = 0) const;	    // GDB: "where COUNT"
     string pwd_command() const;	                    // GDB: "pwd "
-    string frame_command(string depth = "") const;  // GDB: "frame DEPTH"
+    string frame_command(int number) const;         // GDB: "frame NUMBER"
+    string frame_command() const;                   // GDB: "frame"
+    string func_command() const;                    // DBX: "func"
     string echo_command(string text) const;         // GDB: "echo TEXT"
     string whatis_command(string expr) const;       // GDB: "whatis EXPR"
     string dereferenced_expr(string expr) const;    // GDB: "*EXPR"
     string address_expr(string expr) const;         // GDB: "&EXPR"
+    string index_expr(string expr, int index) const; // GDB: "EXPR[INDEX]"
+    int default_index_base() const;                 // GDB: 0 in C, else 1
     string info_locals_command() const;	            // GDB: "info locals"
     string info_args_command() const;	            // GDB: "info args"
-    string disassemble_command(string pc) const;    // GDB: "disassemble PC"
+    string disassemble_command(string start, string end = "") const;
+                                                // GDB: "disassemble START END"
     string make_command(string target) const;       // GDB: "make TARGET"
+    string jump_command(string pc) const;           // GDB: "jump PC"
+    string regs_command(bool all = true) const;	    // GDB: "info registers"
+    string kill_command() const;                    // GDB: "kill"
+    string enable_command(string bp = "") const;    // GDB: "enable BP"
+    string disable_command(string bp = "") const;   // GDB: "disable BP"
+    string delete_command(string bp = "") const;    // GDB: "delete BP"
+    string ignore_command(string bp, int count) const; 
+                                                    // GDB: "ignore BP COUNT"
+    string condition_command(string bp, string expr) const; 
+				                    // GDB: "cond BP EXPR"
+    string shell_command(string cmd) const;	    // GDB: "shell CMD"
+    string debug_command(string program = "") const; // GDB: "file PROGRAM"
+    string signal_command(int sig) const;           // GDB: "signal SIG"
+
+    // Default history file
+    string history_file() const;                    // GDB: "~/.gdb_history"
+
+    // Send DATA to process
+    virtual int write(const char *data, int length)
+    {
+	last_written = string(data, length);
+	echoed_characters = 0;
+	return TTYAgent::write(data, length);
+    }
+
+    // Custom function
+    int write(const string& data)
+    {
+	return write(data.chars(), data.length());
+    }
+
+    bool ends_with_prompt(const string& answer);
+    bool ends_with_secondary_prompt(const string& answer);
 
 private:
     bool questions_waiting;
 
     void* _qu_data;
 
-    int     qu_index, _qu_count;
-    string* cmd_array;
-    string* complete_answers;
-    void**  _qu_datas;
+    int     qu_index;
+    int    _qu_count;
+    StringArray cmd_array;
+    StringArray complete_answers;
+    VoidArray _qu_datas;
     void*   _qa_data;
 
     OAProc   _on_answer;
@@ -365,32 +480,38 @@ private:
     OQCProc  _on_question_completion;
     OQACProc _on_qu_array_completion;
 
-    void    init_qu_array (string   cmds [],
-			   void*    qu_datas [],
+    void    init_qu_array (const StringArray& cmds,
+			   const VoidArray& qu_datas,
 			   int      qu_count,
 			   OQACProc on_qu_array_completion,
 			   void*    qa_data);
-    bool ends_with_prompt(const string& answer);
-    bool ends_with_secondary_prompt(const string& answer);
+
     string requires_reply(const string& answer);
 
-    void cut_off_prompt(string& answer);
-    void strip_comments(string& answer);
-    void strip_control(string& answer);
+    void cut_off_prompt(string& answer) const;
+    void strip_dbx_comments(string& answer) const;
+    void strip_control(string& answer) const;
 
-    void normalize(string& answer);
+    void normalize_answer(string& answer) const;
+    void normalize_address(string& addr) const;
+
+    void handle_echo(string& answer);
+    void handle_more(string& answer);
+    void handle_reply(string& answer);
+    void handle_input(string& answer);
+    void handle_died();
 
 protected:
     string complete_answer;
 
-    static void InputHP(Agent*, void*, void*);
-    static void PanicHP(Agent*, void*, void*);
+    static void InputHP  (Agent *, void *, void *);
+    static void PanicHP  (Agent *, void *, void *);
+    static void StrangeHP(Agent *, void *, void *);
+    static void DiedHP   (Agent *, void *, void *);
 
-    static void traceInputHP(Agent*, void*, void*);
-    static void traceOutputHP(Agent*, void*, void*);
-    static void traceErrorHP(Agent*, void*, void*);
-
-    virtual int setupChildCommunication();
+    static void traceInputHP (Agent *, void *, void *);
+    static void traceOutputHP(Agent *, void *, void *);
+    static void traceErrorHP (Agent *, void *, void *);
 };
 
 #endif // _DDD_GDBAgent_h
