@@ -1,4 +1,4 @@
-// $Id: Graph.h,v 1.12 1997/04/25 06:36:17 zeller Exp $
+// $Id: Graph.h,v 1.15 1997/12/15 18:53:50 zeller Exp $
 // Graph Class
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_Graph_h
 #define _DDD_Graph_h
@@ -48,6 +48,8 @@ private:
     GraphNode *_firstNode;	// circular list (0 if empty)
     GraphEdge *_firstEdge;	// circular list (0 if empty)
 
+    Graph& operator = (const Graph&) { assert(0); return *this; }
+
 protected:
     void addNodes(GraphNode* nodes);
     void addEdges(GraphEdge* edges);
