@@ -1,4 +1,4 @@
-// $Id: GraphEdge.h,v 1.11 1997/04/25 06:36:19 zeller Exp $
+// $Id: GraphEdge.h,v 1.15 1997/12/15 18:53:51 zeller Exp $
 // GraphEdge Class
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_GraphEdge_h
 #define _DDD_GraphEdge_h
@@ -38,6 +38,7 @@
 #include "bool.h"
 #include "GraphGC.h"
 #include "TypeInfo.h"
+#include "assert.h"
 
 class GraphEdge {
 public:
@@ -67,6 +68,8 @@ private:
     GraphEdge *prev;
     Graph *graph;
 
+    GraphEdge& operator = (const GraphEdge&) { assert(0); return *this; }
+
 protected:
     // Graphics
     virtual void _draw(Widget w, 
@@ -81,6 +84,7 @@ protected:
 
     // Copy Constructor
     GraphEdge(const GraphEdge& edge):
+	_id(),
         _from(0),
         _to(0),
 	_hidden(edge._hidden),
@@ -96,6 +100,7 @@ protected:
 public:
     // Constructor
     GraphEdge(GraphNode *f, GraphNode *t):
+	_id(),
         _from(f), _to(t), 
         _hidden(false),
         _nextFrom(0), _nextTo(0),
@@ -126,7 +131,7 @@ public:
     }
 
     // Printing
-    void _print(ostream& os, const GraphGC& gc) const;
+    virtual void _print(ostream& os, const GraphGC& gc) const;
 
     // representation invariant
     virtual bool OK() const;
