@@ -1,4 +1,4 @@
-// $Id: GraphEdit.h,v 1.15 1997/04/25 06:36:23 zeller Exp $
+// $Id: GraphEdit.h,v 1.18 1998/01/02 13:51:29 zeller Exp $
 // GraphEdit Widget -- public interface
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_GraphEdit_h
 #define _DDD_GraphEdit_h
@@ -73,6 +73,7 @@
 #define XtNcompareNodesCallback     "compareNodes"
 #define XtNpreLayoutCallback        "preLayout"
 #define XtNpostLayoutCallback       "postLayout"
+#define XtNpreSelectionCallback     "preSelection"
 #define XtNselectTile               "selectTile"
 #define XtNrotation		    "rotation"
 #define XtNautoLayout		    "autoLayout"
@@ -149,7 +150,10 @@ struct GraphEditPositionChangedInfo {
     Boolean   is_last;         // True iff no more changes follow
 
     GraphEditPositionChangedInfo():
-        graph(0), node(0), is_last(False)
+        graph(0), node(0), 
+	old_position(),
+	new_position(),
+	is_last(False)
     {}
     GraphEditPositionChangedInfo(const GraphEditPositionChangedInfo& info):
         graph(info.graph), node(info.node), 
@@ -157,19 +161,44 @@ struct GraphEditPositionChangedInfo {
         new_position(info.new_position),
         is_last(info.is_last)
     {}
+    GraphEditPositionChangedInfo& 
+        operator = (const GraphEditPositionChangedInfo& info)
+    {
+	graph        = info.graph;
+	node         = info.node;
+	old_position = info.old_position;
+	new_position = info.new_position;
+	is_last      = info.is_last;
+	return *this;
+    }
 };
 
-struct GraphEditSelectionChangedInfo {
+struct GraphEditPreSelectionInfo {
     Graph     *graph;		// Graph this node is in
+    GraphNode *node;		// Selected node
+    Boolean   double_click;	// Double-click?
+    Boolean   doit;		// Flag: do default action?
 
-    GraphEditSelectionChangedInfo():
-        graph(0)
+    GraphEditPreSelectionInfo():
+        graph(0), node(0), double_click(False), doit(True)
     {}
-    GraphEditSelectionChangedInfo(const GraphEditSelectionChangedInfo& info):
-        graph(info.graph)
+    GraphEditPreSelectionInfo(const GraphEditPreSelectionInfo& info):
+        graph(info.graph), node(info.node), double_click(info.double_click),
+	doit(info.doit)
     {}
+    GraphEditPreSelectionInfo& 
+        operator = (const GraphEditPreSelectionInfo& info)
+    {
+	graph        = info.graph;
+	node         = info.node;
+	double_click = info.double_click;
+	doit         = info.doit;
+	return *this;
+    }
 };
 
+typedef GraphEditPreSelectionInfo GraphEditSelectionChangedInfo;
+
 struct GraphEditLayoutInfo {
     Graph     *graph;		// Graph this node is in
     LayoutMode mode;		// Current layout mode
@@ -181,6 +210,14 @@ struct GraphEditLayoutInfo {
     GraphEditLayoutInfo(const GraphEditLayoutInfo& info):
         graph(info.graph), mode(info.mode), rotation(info.rotation)
     {}
+    GraphEditLayoutInfo& 
+        operator = (const GraphEditLayoutInfo& info)
+    {
+	graph    = info.graph;
+	mode     = info.mode;
+	rotation = info.rotation;
+	return *this;
+    }
 };
 
 struct GraphEditCompareNodesInfo {
@@ -201,6 +238,15 @@ struct GraphEditCompareNodesInfo {
 	node2(info.node2),
 	result(info.result)
     {}
+    GraphEditCompareNodesInfo& 
+        operator = (const GraphEditCompareNodesInfo& info)
+    {
+        graph  = info.graph;
+	node1  = info.node1;
+	node2  = info.node2;
+	result = info.result;
+	return *this;
+    }
 };
 
 
