@@ -1,4 +1,4 @@
-// $Id: GraphGC.h,v 1.11 1997/04/25 06:36:26 zeller Exp $
+// $Id: GraphGC.h,v 1.14 1997/12/15 18:53:51 zeller Exp $
 // Graph graphics context
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_GraphGC_h
 #define _DDD_GraphGC_h
@@ -129,6 +129,33 @@ struct GraphGC {
 	printGC(g.printGC),
 	printSelectedNodesOnly(g.printSelectedNodesOnly)
     {}
+
+    // Assignment
+    GraphGC& operator = (const GraphGC& g)
+    {
+	if (&g != this)
+	{
+	    redraw                 = g.redraw;
+	    nodeGC                 = g.nodeGC;
+	    hintGC                 = g.hintGC;
+	    edgeGC                 = g.edgeGC;
+	    invertGC               = g.invertGC;
+	    clearGC                = g.clearGC;
+	    offsetIfSelected       = g.offsetIfSelected;
+	    edgeAttachMode         = g.edgeAttachMode;
+	    drawArrowHeads         = g.drawArrowHeads;
+	    drawHints              = g.drawHints;
+	    hintSize               = g.hintSize;
+	    arrowAngle             = g.arrowAngle;
+	    arrowLength            = g.arrowLength;
+	    selfEdgeDiameter       = g.selfEdgeDiameter;
+	    selfEdgePosition       = g.selfEdgePosition;
+	    selfEdgeDirection      = g.selfEdgeDirection;
+	    printGC                = g.printGC;
+	    printSelectedNodesOnly = g.printSelectedNodesOnly;
+	}
+	return *this;
+    }
 };
 
 #endif // _DDD_GraphGC_h
