@@ -1,4 +1,4 @@
-// $Id: GraphNodeI.h,v 1.14 1997/04/25 06:36:29 zeller Exp $
+// $Id: GraphNodeI.h,v 1.18 1998/01/02 17:13:53 zeller Exp $
 // GraphNode class structure
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_GraphNodeI_h
 #define _DDD_GraphNodeI_h
@@ -62,9 +62,12 @@ private:
     GraphNode *prev;		// For collectors
     Graph *graph;		// For collectors
 
+    GraphNode& operator = (const GraphNode&) { assert(0); return *this; }
+
 protected:
     // Copy Constructor
     GraphNode(const GraphNode& node):
+	_id(),
 	_selected(node._selected),
 	_hidden(node._hidden),
 	_redraw(node._redraw),
@@ -72,7 +75,8 @@ protected:
 	_firstTo(0),
 	next(0),
 	prev(0),
-	graph(0)
+	graph(0),
+	count(0)
     {}
 
 public:
@@ -80,7 +84,7 @@ public:
 
     // Constructor
     GraphNode():
-	_selected(false), _hidden(false), _redraw(false),
+	_id(), _selected(false), _hidden(false), _redraw(false),
 	_firstFrom(0), _firstTo(0), next(0), prev(0), graph(0), count(0)
     {}
 
@@ -107,7 +111,7 @@ public:
     GraphEdge *firstTo() const { return _firstTo; }
     GraphEdge *nextTo(GraphEdge *ref) const;
 
-    // resources
+    // Resources
     virtual const BoxPoint&  pos() const                              = 0;
     virtual const BoxRegion& region(const GraphGC& gc) const          = 0;
     virtual const BoxRegion& highlightRegion(const GraphGC& gc) const = 0;
@@ -119,21 +123,37 @@ public:
 	return string(os);
     }
 
-    // types
+    // Shortcuts
+    const BoxPoint& origin(const GraphGC& gc) const
+    {
+	return region(gc).origin();
+    }
+    const BoxSize& space(const GraphGC& gc) const
+    {
+	return region(gc).space();
+    }
+
+    // Types
     virtual bool isHint() const { return false; }
 
-    // move
+    // Move
     virtual void moveTo(const BoxPoint& newPos) = 0;
 
-    // draw
+    // Compute position for ORIGIN
+    virtual BoxPoint originToPos(const BoxPoint& origin, const GraphGC&) const
+    {
+	return origin;
+    }
+
+    // Draw
     virtual void draw(Widget, 
 		      const BoxRegion&, 
 		      const GraphGC&) const
     {
-	// default: do nothing
+	// Default: do nothing
     }
 
-    // custom drawing functions
+    // Custom drawing functions
     void draw(Widget w, const BoxRegion& exposed) const
     {
 	draw(w, exposed, GraphGC());
@@ -145,13 +165,13 @@ public:
 	    GraphGC());
     }
 
-    // printing
+    // Printing
     virtual void _print(ostream&, const GraphGC&) const
     {
-	// default: do nothing
+	// Default: do nothing
     }
 
-    // representation invariant
+    // Representation invariant
     virtual bool OK() const;
 };
 
