@@ -1,4 +1,4 @@
-// $Id: HandlerL.h,v 1.8 1997/04/25 06:36:31 zeller Exp $
+// $Id: HandlerL.h,v 1.11 1997/12/15 18:53:53 zeller Exp $
 // General-purpose Handler Manager
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_HandlerList_h
 #define _DDD_HandlerList_h
@@ -34,6 +34,8 @@
 #endif
 
 #include "compare.h"
+#include "bool.h"
+#include "assert.h"
 
 typedef void (*HandlerProc)(void *source,	// handler source
 			    void *client_data,  // data supplied by client
@@ -47,13 +49,18 @@ private:
 	HandlerProc proc;		// handling procedure
 	void        *client_data;	// data supplied by client
 	HandlerRec  *next;		// for collectors
-	int     remove_me;              // Flag: to be removed?
+	bool    remove_me;              // Flag: to be removed?
 	
 	// Constructor
 	HandlerRec(HandlerProc p, void *c, HandlerRec *n = 0):
 	    proc(p), client_data(c), next(n), 
-	    remove_me(0)
+	    remove_me(false)
         {}
+
+    private:
+	HandlerRec(const HandlerRec&):
+	    proc(0), client_data(0), next(0), remove_me(false) { assert(0); }
+	HandlerRec& operator = (const HandlerRec&) { assert(0); return *this; }
     };
 
     static int compare(const HandlerRec& l1, const HandlerRec& l2)
@@ -71,6 +78,9 @@ protected:
     // Remove all handlers marked as "remove me"
     void processRemovals(unsigned type) const;
 
+private:
+    HandlerList& operator = (const HandlerList&) { assert(0); return *this; }
+
 public:
     // Constructor
     HandlerList(unsigned n = 10);
