@@ -1,4 +1,4 @@
-// $Id: HatBox.h,v 1.8 1997/04/25 06:36:33 zeller Exp $
+// $Id: HatBox.h,v 1.11 1997/12/15 18:53:54 zeller Exp $
 // Deklaration Klasse HatBox
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_HatBox_h
 #define _DDD_HatBox_h
@@ -34,9 +34,9 @@
 #endif
 
 
-// Eine HatBox stuelpt sich wie ein Hut ueber eine andere Box,
-// um bestimmte Eigenschaften zu veraendern 
-// (insbesondere Groesse, Ausdehnung usw.).
+// Eine HatBox stuelpt sich wie ein Hut ueber eine andere Box, um
+// bestimmte Eigenschaften zu veraendern (insbesondere Groesse,
+// Ausdehnung usw.).
 
 #include "Box.h"
 #include "Widget.h"
@@ -70,6 +70,9 @@ protected:
 	return _box->findTag(p);
     }
 
+private:
+    HatBox& operator = (const HatBox&) { assert(0); return *this; }
+
 public:
     HatBox(Box *box, char *t = "HatBox"): 
 	Box(box->size(), box->extend(), t), _box(box->link())
