@@ -1,4 +1,4 @@
-// $Id: LessTifH.h,v 1.1 1997/05/27 15:23:35 zeller Exp $ -*- C++ -*-
+// $Id: LessTifH.h,v 1.3 1997/10/03 10:38:17 zeller Exp $ -*- C++ -*-
 // Check whether LessTif hacks are enabled
 
 // Copyright (C) 1997 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_LessTifHacks_h
 #define _DDD_LessTifHacks_h
@@ -33,9 +33,8 @@
 #pragma interface
 #endif
 
-#include "bool.h"
-
-extern bool lesstif_hacks_enabled;
+// The LessTif version number: 1000 * version + revision
+extern int lesstif_version;
 
 #endif // _DDD_LessTifHacks_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
