@@ -1,4 +1,4 @@
-// $Id: LetNode.h,v 1.8 1997/04/25 06:36:43 zeller Exp $
+// $Id: LetNode.h,v 1.11 1997/12/15 18:53:55 zeller Exp $
 // Deklaration Klasse LetNode
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_LetNode_h
 #define _DDD_LetNode_h
@@ -94,6 +94,9 @@ protected:
     char *func_name() const       { assert(0); return "let"; }
     const Box *call(Box *) const  { assert(0); return 0; }
 
+private:
+    LetNode& operator = (const LetNode&) { assert(0); return *this; }
+
 public:
     // LetNode erzeugen
     LetNode(VSLNode *p, VSLNode *a, VSLNode *b, char *type = "LetNode"):
