@@ -1,4 +1,4 @@
-// $Id: LineGraphE.h,v 1.12 1997/04/25 06:36:48 zeller Exp $
+// $Id: LineGraphE.h,v 1.14 1997/10/03 10:38:23 zeller Exp $
 // LineGraphEdge class: GraphEdge with drawing capabilities
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_LineGraphEdge_h
 #define _DDD_LineGraphEdge_h
@@ -101,6 +101,9 @@ public:
     // Destructor
     virtual ~LineGraphEdge() {}
 
+    // Printing
+    void _print(ostream& os, const GraphGC &gc) const;
+
     GraphEdge *dup() const
     {
 	return new LineGraphEdge(*this);
