@@ -1,4 +1,4 @@
-// $Id: ListBox.h,v 1.9 1997/04/25 06:36:50 zeller Exp $
+// $Id: ListBox.h,v 1.12 1997/12/15 18:53:56 zeller Exp $
 // Klasse ListBox (Deklaration)
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_ListBox_h
 #define _DDD_ListBox_h
@@ -56,6 +56,8 @@ private:
     Box     *&_head()   { return _child(0); }
     Box     *&_tail()   { return _child(1); }
 
+    ListBox& operator = (const ListBox&) { assert(0); return *this; }
+
 public:
     const Box *head() const 
     { 
