@@ -1,4 +1,4 @@
-// $Id: ListNode.h,v 1.7 1997/04/25 06:36:52 zeller Exp $
+// $Id: ListNode.h,v 1.10 1997/12/15 18:53:57 zeller Exp $
 // Deklaration Klasse ListNode
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_ListNode_h
 #define _DDD_ListNode_h
@@ -69,6 +69,9 @@ protected:
 	    *_tail == *(((ListNode *)&node)->_tail);    // dirty trick
     }
 
+private:
+    ListNode& operator = (const ListNode&) { assert(0); return *this; }
+
 public:
     ListNode(VSLNode *hd, VSLNode *tl, char *type = "ListNode"):
 	VSLNode(type), _head(hd), _tail(tl)
