@@ -1,4 +1,4 @@
-// $Id: MakeMenu.h,v 1.10 1997/04/25 06:36:59 zeller Exp $
+// $Id: MakeMenu.h,v 1.14 1997/10/23 11:40:39 zeller Exp $
 // Simple interface to motif menus
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_MakeMenu_h
 #define _DDD_MakeMenu_h
@@ -34,19 +34,21 @@
 // Main types
 typedef int MMType;
 
-const MMType MMPush        = 0;	// create PushButton (default)
-const MMType MMToggle      = 1;	// create ToggleButton
-const MMType MMMenu        = 2;	// create CascadeButton with menu
-const MMType MMSeparator   = 3;	// create Separator
-const MMType MMLabel       = 4;	// create Label
-const MMType MMRadioMenu   = 5;	// create CascadeButton with RadioBox menu
-const MMType MMOptionMenu  = 6;  // create an option menu
-const MMType MMPanel       = 7;  // create a panel
-const MMType MMRadioPanel  = 8;  // create a panel with RadioBox menu
-const MMType MMButtonPanel = 9;  // like MMRadioPanel, but no radio behavior
-const MMType MMScale      = 10;  // create a scale
+const MMType MMPush        =  0; // create PushButton (default)
+const MMType MMToggle      =  1; // create ToggleButton
+const MMType MMMenu        =  2; // create CascadeButton with menu
+const MMType MMSeparator   =  3; // create Separator
+const MMType MMLabel       =  4; // create Label
+const MMType MMRadioMenu   =  5; // create CascadeButton with RadioBox menu
+const MMType MMOptionMenu  =  6; // create an option menu
+const MMType MMPanel       =  7; // create a panel
+const MMType MMRadioPanel  =  8; // create a panel with RadioBox menu
+const MMType MMButtonPanel =  9; // like MMRadioPanel, but no radio behavior
+const MMType MMScale       = 10; // create a scale
+const MMType MMTextField   = 11; // create a text field
+const MMType MMEnterField  = 12; // like MMTextField, but use Enter to activate
 
-const MMType MMTypeMask  = 15;	// mask to find type
+const MMType MMTypeMask    = 15; // mask to find type
 
 
 // Special attributes, to be ORed with types
@@ -91,7 +93,6 @@ typedef void (*MMItemProc)(MMDesc items[], XtPointer closure);
 
 
 // Functions
-
 Widget MMcreatePulldownMenu      (Widget parent, String name, MMDesc items[]);
 Widget MMcreateRadioPulldownMenu (Widget parent, String name, MMDesc items[]);
 Widget MMcreatePopupMenu         (Widget parent, String name, MMDesc items[]);
@@ -107,10 +108,13 @@ void   MMonItems        (MMDesc items[], MMItemProc proc,
 			 XtPointer closure = 0);
 
 // Conveniences
-
 #define MMNoCB { NULL }
 #define MMEnd  { NULL }
 #define MMSep  { "separator", MMSeparator }
 
+// New resources
+#define XtNpushMenuPopupTime  "pushMenuPopupTime"
+#define XtCPushMenuPopupTime  "PushMenuPopupTime"
+
 #endif // _DDD_MakeMenu_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
