@@ -1,4 +1,4 @@
-// $Id: PosBuffer.h,v 1.12 1997/04/25 06:37:17 zeller Exp $
+// $Id: PosBuffer.h,v 1.20 1997/12/15 12:59:52 zeller Exp $
 // Filter position information from GDB output.
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_PosBuffer_h
 #define _DDD_PosBuffer_h
@@ -44,7 +44,7 @@
 class PosBuffer {
     // What was in the previous answer?
     enum ReadState {Null, PosPart, PosComplete};
-    
+
     string pos_buffer;
     string func_buffer;
     string answer_buffer;	// Possible parts of positions
@@ -52,51 +52,67 @@ class PosBuffer {
     ReadState already_read;
 
     bool started;		// Program has started
+    bool terminated;		// Program has terminated
+    bool signaled;		// Program has received a signal
     bool recompiled;		// Program has been recompiled
 
+    string auto_cmd_buffer;	// AutoCommand found
+
 public:
+    // Call this before filtering any new output.
+    void clear()
+    {
+	pos_buffer      = "";
+	func_buffer     = "";
+	answer_buffer   = "";
+	pc_buffer       = "";
+	already_read    = Null;
+	started         = false;
+	terminated      = false;
+	signaled        = false;
+	recompiled      = false;
+	auto_cmd_buffer = "";
+    }
+
     // Constructor
-    PosBuffer () :
-	pos_buffer(""),
-	func_buffer(""),
-	answer_buffer(""),
-	pc_buffer(""),
-	already_read(Null),
-	started(false),
-	recompiled(false)
-    {}
+    PosBuffer()
+	: pos_buffer(""),
+	  func_buffer(""),
+	  answer_buffer(""),
+	  pc_buffer(""),
+	  already_read(Null),
+	  started(false),
+	  terminated(false),
+	  signaled(false),
+	  recompiled(false),
+	  auto_cmd_buffer("")
+    {
+	// clear();
+    }
 
     // Filter positions from ANSWER and buffer them.  ANSWER contains
     // any remaining parts.
-    void filter (string& answer);
+    void filter(string& answer);
 
     // GDB output has ended.  Return any non-position parts.
-    string answer_ended ();
+    string answer_ended();
 
     // Did we find a position in the last output?
-    bool pos_found () const { return already_read == PosComplete; }
-    bool pc_found ()  const { return pc_buffer != ""; }
+    bool pos_found() const      { return already_read == PosComplete; }
+    bool pc_found()  const      { return pc_buffer != ""; }
+    bool auto_cmd_found() const { return auto_cmd_buffer != ""; }
 
     // Return the position found.
-    const string& get_position () const { return pos_buffer; }
-    const string& get_function () const { return func_buffer; }
-    const string& get_pc ()       const { return pc_buffer; }
+    const string& get_position() const { return pos_buffer; }
+    const string& get_function() const { return func_buffer; }
+    const string& get_pc()       const { return pc_buffer; }
+    const string& get_auto_cmd() const { return auto_cmd_buffer; }
 
     // Other properties.
     bool started_found()    const { return started; }
+    bool terminated_found() const { return terminated; }
+    bool signaled_found()   const { return signaled; }
     bool recompiled_found() const { return recompiled; }
-
-    // Call this before filtering any new output.
-    void clear ()
-    {
-	pos_buffer    = "";
-	func_buffer   = "";
-	answer_buffer = "";
-	pc_buffer     = "";
-	already_read  = Null;
-	started       = false;
-	recompiled    = false;
-    }
 };
 
 // A regex for C addresses ("0xdead"), Modula-2 addresses ("0BEEFH"),
@@ -105,7 +121,22 @@ public:
 // format "16_FFFF" is lost in the mist of time.
 #define RXADDRESS "(0x[0-9a-fA-F]+|0[0-9a-fA-F]+[hH]|H'[0-9a-fA-F]+" \
                   "|00+|[(]nil[)]|NIL|16_[0-9a-f]+)"
-extern regex rxaddress;
+#if RUNTIME_REGEX
+extern const regex rxaddress;
+#endif
+
+// Possible start of address - simple prefix of RXADDRESS
+#define RXADDRESS_START "[0H]"
+
+#if RUNTIME_REGEX
+extern const regex rxaddress_start;
+#endif
+
+// An even faster check - for hand-written parsers
+inline bool is_address_start(char c)
+{
+    return c == '0' || c == 'H';
+}
 
 #endif // _DDD_PosBuffer_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
