@@ -1,4 +1,4 @@
-// $Id: PosGraphN.h,v 1.9 1997/04/25 06:37:19 zeller Exp $
+// $Id: PosGraphN.h,v 1.11 1998/01/02 17:13:55 zeller Exp $
 // PosGraphNode class: GraphNode with position
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_PosGraphNode_h
 #define _DDD_PosGraphNode_h
@@ -60,10 +60,14 @@ public:
     // Destructor
     virtual ~PosGraphNode() {}
 
+    // Position change handler: return true iff ok
+    static bool (*MoveCB)(PosGraphNode *node, const BoxPoint& newPos);
+
     // Move
     virtual void moveTo(const BoxPoint& newPos)
     {
-	_pos = newPos;
+	if (_pos != newPos && MoveCB(this, newPos))
+	    _pos = newPos;
     }
 
     // Attributes
