@@ -1,4 +1,4 @@
-// $Id: Range.h,v 1.6 1997/04/25 06:37:24 zeller Exp $
+// $Id: Range.h,v 1.8 1997/12/15 12:59:54 zeller Exp $
 // Klasse "Range" (Deklaration)
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_Range_h
 #define _DDD_Range_h
@@ -32,18 +32,19 @@
 #include <iostream.h>
 
 struct Range {
-    int start;          // Beginn Bereich
-    int end;            // Ende Bereich
-    Range(int x = 0) {
-	start = end = x;
-    }
-    Range(int s, int e) {
-	start = s; end = e;
-    }
-    int operator == (Range r) {
+    int start;			// Start of range
+    int end;			// End of range
+
+    Range(int x = 0)
+	: start(x), end(x) {}
+    Range(int s, int e)
+	: start(s), end(e) {}
+    int operator == (const Range& r) 
+    {
 	return start == r.start && end == r.end;
     }
-    int operator != (Range r) {
+    int operator != (const Range& r)
+    {
 	return start != r.start || end != r.end;
     }
     friend ostream& operator << (ostream& s, Range& range);
