@@ -1,4 +1,4 @@
-// $Id: RegionGN.h,v 1.12 1997/04/25 06:37:26 zeller Exp $
+// $Id: RegionGN.h,v 1.14 1998/01/02 17:13:57 zeller Exp $
 // RegionGraphNode class: PosGraphNode with rectangular region
 // centered around position
 
@@ -25,7 +25,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_RegionGraphNode_h
 #define _DDD_RegionGraphNode_h
@@ -80,13 +80,23 @@ public:
 	center();
     }
 
+    // Size change handler: return true iff ok
+    static bool (*ResizeCB)(RegionGraphNode *node, 
+			    const BoxSize& newSize);
+
     // Assign new size
     virtual void resize(const BoxSize& newSize)
     {
-	_region.space() = newSize;
-	center();
+	if (newSize != _region.space() && ResizeCB(this, newSize))
+	{
+	    _region.space() = newSize;
+	    center();
+	}
     }
 
+    // Compute position for ORIGIN
+    virtual BoxPoint originToPos(const BoxPoint& origin, const GraphGC&) const;
+
     // Draw
     virtual void draw(Widget w,
 		      const BoxRegion& exposed,
