@@ -1,4 +1,4 @@
-// $Id: SignalB.h,v 1.8 1997/04/25 06:37:31 zeller Exp $ -*- C++ -*-
+// $Id: SignalB.h,v 1.12 1997/12/16 11:14:40 zeller Exp $ -*- C++ -*-
 // Block signals for the lifetime of this object (protect critical sections)
 
 // Copyright (C) 1996 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_SignalBlocker_h
 #define _DDD_SignalBlocker_h
@@ -35,6 +35,7 @@
 
 #include <sys/types.h>
 #include <signal.h>
+#include "assert.h"
 
 // A SignalBlocker is used to protect critical sections:
 // 
@@ -62,8 +63,22 @@ private:
 #endif
 
     // No assignments and copies
-    void operator = (const SignalBlocker&) {}
-    SignalBlocker(const SignalBlocker&) {}
+    SignalBlocker& operator = (const SignalBlocker&) 
+    {
+	assert(0);
+	return *this;
+    }
+
+    SignalBlocker(const SignalBlocker& sb) 
+	:
+#ifdef SIG_SETMASK
+	old_set(sb.old_set)
+#else
+	old_mask(sb.old_mask)
+#endif
+     {
+	 assert(0);
+     }
 
 public:
     // Constructor - block signal SIGNUM
