@@ -1,7 +1,7 @@
-// $Id: SourceView.h,v 1.60 1997/05/30 12:24:06 zeller Exp $
+// $Id: SourceView.h,v 1.88 1998/01/02 10:56:22 zeller Exp $
 // View the Source.
 
-// Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
+// Copyright (C) 1995-1997 Technische Universitaet Braunschweig, Germany.
 // Written by Dorothea Luetkehaus <luetke@ips.cs.tu-bs.de>
 // and Andreas Zeller (zeller@ips.cs.tu-bs.de).
 // 
@@ -25,7 +25,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 //-----------------------------------------------------------------------------
 // This class creates the source view window and provides necessary
@@ -75,6 +75,10 @@
 extern GDBAgent* gdb;
 extern ArgField* source_arg;
 
+
+// Maximum number of simultaneous glyphs on the screen
+#define MAX_GLYPHS 20
+
 //-----------------------------------------------------------------------------
 class SourceView {
     static void add_to_history(const string& file_name, int line);
@@ -86,14 +90,12 @@ class SourceView {
     static void line_popup_setCB         (Widget, XtPointer, XtPointer);
     static void line_popup_set_tempCB    (Widget, XtPointer, XtPointer);
     static void line_popup_temp_n_contCB (Widget, XtPointer, XtPointer);
-
-    static void address_popup_setCB         (Widget, XtPointer, XtPointer);
-    static void address_popup_set_tempCB    (Widget, XtPointer, XtPointer);
-    static void address_popup_temp_n_contCB (Widget, XtPointer, XtPointer);
+    static void line_popup_set_pcCB      (Widget, XtPointer, XtPointer);
 
     static void bp_popup_infoCB          (Widget, XtPointer, XtPointer);
     static void bp_popup_deleteCB        (Widget, XtPointer, XtPointer);
     static void bp_popup_disableCB       (Widget, XtPointer, XtPointer);
+    static void bp_popup_set_pcCB        (Widget, XtPointer, XtPointer);
 
     static void text_popup_printCB       (Widget, XtPointer, XtPointer);
     static void text_popup_dispCB        (Widget, XtPointer, XtPointer);
@@ -131,15 +133,7 @@ class SourceView {
     static void SelectRegisterCB (Widget, XtPointer, XtPointer);
     static void SelectThreadCB   (Widget, XtPointer, XtPointer);
 
-    static Widget create_glyph(Widget form_w, String name, 
-			       char *bits, int width, int height);
-    static void map_glyph(Widget& w, Position x, Position y);
-    static void unmap_glyph(Widget w);
-
     static void update_title ();
-    static void update_glyphs ();
-    static void UpdateGlyphsWorkProc(XtPointer, XtIntervalId *);
-    static Boolean CreateGlyphsWorkProc(XtPointer);
     static void MoveCursorToGlyphPosCB(Widget, XtPointer, XtPointer);
     static int line_height (Widget text_w);
 
@@ -150,11 +144,19 @@ class SourceView {
     static void refresh_source_bp_disp ();
     static void refresh_code_bp_disp ();
 
-    // Findet zu pos die passende Zeilennummer.
-    // in_text==true wenn pos im Quelltext-Bereich ist.
-    // bp_nr ist die Nr des Brekpoints, 
-    // der an Position pos dargestellt wird, 0 sonst.
-    //
+    static void clearBP(void *client_data, XtIntervalId *timer);
+    static void clearJumpBP(const string& answer, void *client_data);
+
+    // Move breakpoint NR to ADDRESS
+    static void move_bp(int nr, const string& address, Widget origin = 0);
+
+    // Set condition of breakpoint NR to COND
+    static void set_bp_cond(int nr, const string& cond, Widget origin = 0);
+
+    // Find the line number at POS.  LINE_NR becomes the line number
+    // at POS.  IN_TEXT becomes true iff POS is in the source area.
+    // BP_NR is the number of the breakpoint at POS (none: 0).  Return
+    // false iff failure.
     static bool get_line_of_pos (Widget w,
 				 XmTextPosition pos,
 				 int& line_nr,
@@ -162,41 +164,40 @@ class SourceView {
 				 bool& in_text,
 				 int& bp_nr);
 
-    // Findet von pos ausgehend die Anfangs- und Endposition eines C-Strings.
-    // (text[startpos] ist dann der erste und text[endpos] der letzte Buchstabe
-    // des gefundenen Wortes)
-    //
+    // Find word around POS.  STARTPOS is the first character, ENDPOS
+    // is the last character in the word.
     static void find_word_bounds (Widget w,
 				  const XmTextPosition pos,
 				  XmTextPosition& startpos,
 				  XmTextPosition& endpos);
 
     //-----------------------------------------------------------------------
-    // Aktions-Prozeduren
+    // Action procedures
     //-----------------------------------------------------------------------
     static void srcpopupAct       (Widget, XEvent*, String*, Cardinal*);
     static void startSelectWordAct(Widget, XEvent*, String*, Cardinal*);
     static void endSelectWordAct  (Widget, XEvent*, String*, Cardinal*);
     static void updateGlyphsAct   (Widget, XEvent*, String*, Cardinal*);
+    static void dragGlyphAct      (Widget, XEvent*, String*, Cardinal*);
+    static void followGlyphAct    (Widget, XEvent*, String*, Cardinal*);
+    static void dropGlyphAct      (Widget, XEvent*, String*, Cardinal*);
 
     //-----------------------------------------------------------------------
-    // Timer-Prozeduren
+    // Timer procedures
     //-----------------------------------------------------------------------
     static void setSelection(XtPointer client_data, XtIntervalId *timer);
 
-
     //-----------------------------------------------------------------------
-    // Xt-Zeugs
+    // Action decls
     //-----------------------------------------------------------------------
     static XtActionsRec actions [];
 
     //-----------------------------------------------------------------------
-    // Menues
+    // Menus
     //-----------------------------------------------------------------------
     static MMDesc line_popup[];
     static MMDesc address_popup[];
-    static MMDesc bp_popup_gdb[];
-    static MMDesc bp_popup_dbx[];
+    static MMDesc bp_popup[];
     static MMDesc text_popup[];
     static MMDesc bp_area[];
 
@@ -204,7 +205,7 @@ class SourceView {
     static void set_text_popup_resource(int item, const string& arg);
 
     //-----------------------------------------------------------------------
-    // Daten
+    // Data
     //-----------------------------------------------------------------------
     static StringArray history;
     static int history_position; // Last position in history + 1
@@ -245,13 +246,12 @@ class SourceView {
     static bool thread_dialog_popped_up;      // True if registers are visible
 
     static bool display_glyphs;	              // Display glyphs?
+    static bool display_line_numbers;	      // Display line numbers?
+    
     static bool disassemble;	              // Disassemble code?
     static bool all_registers;	              // Show all registers?
     static bool at_lowest_frame;              // Are we at lowest frame?
-
-    // The indenting amounts
-    static int  bp_indent_amount;   // Source
-    static int  code_indent_amount; // Machine code
+    static bool signal_received;	      // Did we receive a signal?
 
     // Tab width
     static int tab_width;
@@ -269,8 +269,6 @@ class SourceView {
 
     // Return TRUE if breakpoint BP is in current file
     static bool bp_matches(BreakPoint *bp);
-    static string full_path(string file);
-    static const char *basename(const char *);
     static bool file_matches(const string& file1, const string& file2);
     static bool base_matches(const string& file1, const string& file2);
 
@@ -281,6 +279,9 @@ class SourceView {
     // The current source text.
     static string current_source;
 
+    // The current frame number.  (-1 if none)
+    static int current_frame;
+
     // The origin of the current source text.
     static SourceOrigin current_origin;
 
@@ -311,6 +312,7 @@ class SourceView {
     static string last_execution_file;
     static int    last_execution_line;
     static string last_execution_pc;
+    static string last_shown_pc;
     static void _show_execution_position (string file, int line, bool silent);
 
     // Last frame position
@@ -332,53 +334,165 @@ class SourceView {
 			    bool force_reload = false,
 			    bool silent = false);
 
-    static void SetInsertionPosition(Widget w,
-				     XmTextPosition pos, 
+    // Set insertion position to POS.
+    static void SetInsertionPosition(Widget w, XmTextPosition pos, 
 				     bool fromTop = false);
 
+    // Make position POS visible.
+    static void ShowPosition(Widget w, XmTextPosition pos, 
+			     bool fromTop = false);
+
     static bool is_source_widget(Widget w);
     static bool is_code_widget(Widget w);
     static string& current_text(Widget w);
 
+    // Return current breakpoint indent amount
+    static int indent_amount(Widget w);
+
     // Format `where' and `thread' lines
     static void setup_where_line(string& line);
 
     // Assembler code display routines.
-    static Delay *refresh_code_pending;
     static XmTextPosition find_pc(const string& pc);
     static void refresh_codeOQC(const string& answer, void *data);
-    static void refresh_codeWorkProc(XtPointer client_data, XtIntervalId *);
     static void set_code(const string& code,
 			 const string& start,
 			 const string& end);
 
     static MString help_on_bp(int bp, bool detailed);
 
+    // Disassembler stuff
+    // Normalize ADDRESS
+    static void normalize_address(string& address);
+
+    // Make address from ADDRESS
+    static string make_address(long address);
+
+    // Return FUNCTION and OFFSET at ADDRESS
+    static void get_func_at(const string& address, string& func, int& offset);
+    
+    // Check if function at PC is larger than MAX_SIZE
+    static bool function_is_larger_than(string pc, int max_size);
+
+    //-----------------------------------------------------------------------
+    // Glyphs
+    //-----------------------------------------------------------------------
+
+    // Create glyph in FORM_W named NAME from given BITS
+    static Widget create_glyph(Widget form_w, String name, 
+			       char *bits, int width, int height);
+
+    // Map glyph W in (X, Y)
+    static void map_glyph(Widget& w, Position x, Position y);
+
+    // Unmap glyph W
+    static void unmap_glyph(Widget w);
+
+    // Return position during glyph drag and drop
+    static XmTextPosition glyph_position(Widget w, XEvent *e, 
+					 bool normalize = true);
+
+    // Data associated with current drag operation
+    // The Glyph being dragged
+    static Widget current_drag_origin;
+
+    // The breakpoint being dragged, or 0 if execution position
+    static int current_drag_breakpoint;
+
+public:
+    // Horizontal arrow offset (pixels)
+    static int arrow_x_offset;
+
+    // Horizontal breakpoint symbol offset (pixels)
+    static int stop_x_offset;
+
+    // Additional offset for multiple breakpoints (pixels)
+    static int multiple_stop_x_offset;
+
+private:
+    // Glyph locations: x[0] is source, x[1] is code
+    static Widget plain_arrows[2];
+    static Widget grey_arrows[2];
+    static Widget signal_arrows[2];
+    static Widget temp_arrows[2];
+    static Widget plain_stops[2][MAX_GLYPHS + 1];
+    static Widget grey_stops[2][MAX_GLYPHS + 1];
+    static Widget temp_stops[2];
+
+    // Map stop sign in W at position POS.  Get widget from STOPS[COUNT];
+    // store location in POSITIONS.  Return mapped widget (0 if none)
+    static Widget map_stop_at(Widget w, XmTextPosition pos,
+			      Widget stops[], int& count,
+			      TextPositionArray& positions);
+
+    // Map arrow/temp arrow/temp stop in W at POS.  If ORIGIN is
+    // given, use colors from ORIGIN.
+    static Widget map_arrow_at     (Widget w, XmTextPosition pos);
+    static Widget map_temp_arrow_at(Widget w, XmTextPosition pos,
+				    Widget origin = 0);
+    static Widget map_temp_stop_at (Widget w, XmTextPosition pos,
+				    Widget origin = 0);
+    static void copy_colors(Widget w, Widget origin);
+
+    // True if code/source glyphs need to be updated
+    static bool update_code_glyphs;
+    static bool update_source_glyphs;
+
+    // Update glyphs for widget W (0: all)
+    static void update_glyphs(Widget w = 0);
+
+    // Helping background procedures
+    static void UpdateGlyphsWorkProc(XtPointer, XtIntervalId *);
+    static Boolean CreateGlyphsWorkProc(XtPointer);
+
+    // Update all glyphs now (without delay).
+    static void update_glyphs_now();
+
+    // Return all glyphs that would change
+    static const WidgetArray& glyphs_to_be_updated();
+
+    // Helpers needed by glyphs_to_be_changed
+    static bool change_glyphs;
+    static WidgetArray changed_glyphs;
+
+    // Callback when state has been reset
+    static void reset_done(const string& answer, void *data);
+
+    static int max_breakpoint_number_seen;
+
 public:
     // Constructor
-    SourceView (XtAppContext app_context,
-		Widget       parent,
-		int          bp_indent_amount);
+    SourceView (XtAppContext app_context, Widget parent);
 
     enum SearchDirection {forward, backward};
 
     // Set current execution position, based on the GDB position info
     // POSITION; no arg means clear current position.
     // STOPPED indicates that the program just stopped.
+    // SIGNALED indicates that the program received a signal.
     static void show_execution_position (string position = "",
-					 bool stopped = false,
-					 bool silent = false);
+					 bool stopped    = false,
+					 bool signaled   = false,
+					 bool silent     = false);
+
+    // Unset current execution position (program terminated)
+    static void clear_execution_position();
 
     // Set cursor position, based on the GDB position info POSITION
     static void show_position (string position, bool silent = false);
 
-    // Set pc position to location PC; return start of line
-    // If MODE is given, highlight PC line
+    // Set pc position to PC.
+    // If MODE is given, highlight PC line.
+    // STOPPED indicates that the program just stopped.
+    // SIGNALED indicates that the program just received a signal.
     static void show_pc (const string& pc, 
-			 XmHighlightMode mode = XmHIGHLIGHT_NORMAL);
+			 XmHighlightMode mode = XmHIGHLIGHT_NORMAL,
+			 bool stopped  = false,
+			 bool signaled = false);
 
     // Handle breakpoint information
-    static void process_info_bp         (string& info_output);
+    static void process_info_bp         (string& info_output,
+					 const string& break_arg = "");
 
     // Handle 'info line' information
     static void process_info_line_main  (string& info_output);
@@ -417,6 +531,7 @@ public:
     static void find(const string& s,
 		     SearchDirection direction = forward,
 		     bool words_only = false,
+		     bool case_sensitive = false,
 		     Time time = CurrentTime);
 
     // Locate function S; if S is omitted, locate last execution position.
@@ -467,6 +582,9 @@ public:
     // Set whether glyphs are to be displayed
     static void set_display_glyphs(bool value);
 
+    // Set whether line numbers are to be displayed
+    static void set_display_line_numbers(bool value);
+
     // Set whether machine code is to be displayed
     static void set_disassemble(bool value);
 
@@ -479,9 +597,48 @@ public:
     // Maximum length of expr in source popup
     static int max_popup_expr_length;
 
+    // The indenting amounts
+    static int source_indent_amount;         // Source
+    static int code_indent_amount;           // Machine code
+    static int line_indent_amount;           // Extra columns for line numbers
+
+    // The scrolling amounts
+    static int lines_above_cursor;           // Lines to keep before cursor
+    static int lines_below_cursor;           // Lines to keep after cursor
+
+    // The maximum breakpoint number when saving states
+    static int max_breakpoint_number;
+
+    // The next breakpoint number (the highest last seen + 1)
+    static int next_breakpoint_number();
+
+    // Create or clear a breakpoint at position A.  If SET, create a
+    // breakpoint; if not SET, delete it.  If TEMP, make the
+    // breakpoint temporary.  If COND is given, break only iff COND
+    // evals to true.  ORIGIN is the origin.
+    static void set_bp(const string& a, bool set, bool temp, 
+		       const string& cond = "", Widget origin = 0);
+
+    // Custom calls
+    static void create_bp(const string& a, Widget origin = 0);
+    static void create_temp_bp(const string& a, Widget origin = 0);
+    static void clear_bp(const string& a, Widget origin = 0);
+
+    // Create a temporary breakpoint at A and continue execution.
+    static void temp_n_cont(const string& a, Widget origin = 0);
+
+    // Enable or disable breakpoint NR
+    static void enable_bp(int nr,  Widget origin = 0);
+    static void disable_bp(int nr, Widget origin = 0);
+
+    // Move PC to ADDRESS
+    static void move_pc(const string& address, Widget origin = 0);
+
     // Return `clear ARG' command.  If CLEAR_NEXT is set, attempt to
     // guess the next event number and clear this one as well.
-    static string clear_command(string arg, bool clear_next = false);
+    // Consider only breakpoints whose number is >= FIRST_BP.
+    static string clear_command(string arg, bool clear_next = false,
+				int first_bp = 0);
 
     // Return `{ COMMAND; }'
     static string command_list(string cmd);
@@ -513,6 +670,9 @@ public:
     // Get the position of breakpoint NUM
     static string bp_pos(int num);
 
+    // Return the breakpoint at POS (0 if none)
+    static BreakPoint *bp_at(string pos);
+
     // Get the word at position of EVENT
     static string get_word_at_event(Widget w,
 				    XEvent *event,
@@ -524,7 +684,49 @@ public:
 				  XmTextPosition pos,
 				  XmTextPosition& startpos,
 				  XmTextPosition& endpos);
+
+    // Examine DDD state
+
+    // True iff we have some source text
+    static bool have_source() { return current_source.length() != 0; }
+
+    // True iff we have some execution position
+    static bool have_exec_pos() { return last_execution_file != ""; }
+
+    // True iff we have some program counter
+    static bool have_pc() { return last_execution_pc != ""; }
+
+    // True iff we have some selection
+    static bool have_selection();
+
+    // Return current frame (-1 if unknown)
+    static int get_frame() { return current_frame; }
+
+    // Return debugger command(s) to restore current state (breakpoints, etc.)
+    static bool get_state(ostream& os);
+
+    // Clear entire state, using GDB commands
+    static void reset();
+
+    // Helpers
+    static string full_path(string file);
+    static const char *basename(const char *);
 };
 
+inline void SourceView::create_bp(const string& a, Widget w)
+{
+    set_bp(a, true, false, "", w);
+}
+
+inline void SourceView::create_temp_bp(const string& a, Widget w)
+{
+    set_bp(a, true, true, "", w);
+}
+
+inline void SourceView::clear_bp(const string& a, Widget w)
+{
+    set_bp(a, false, false, "", w);
+}
+
 #endif // _DDD_SourceView_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
