@@ -1,4 +1,4 @@
-// $Id: StringBox.h,v 1.7 1997/04/25 06:37:48 zeller Exp $
+// $Id: StringBox.h,v 1.10 1997/12/15 18:54:11 zeller Exp $
 // A String Box contains a string
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_StringBox_h
 #define _DDD_StringBox_h
@@ -52,6 +52,8 @@ private:
     XFontStruct *_font;
     BoxCoordinate _ascent;
 
+    StringBox& operator = (const StringBox&) { assert(0); return *this; }
+
 protected:
     virtual void _draw(Widget w, 
 		       const BoxRegion& region, 
