@@ -1,4 +1,4 @@
-// $Id: TTYAgent.h,v 1.14 1997/04/25 06:37:56 zeller Exp $ -*- C++ -*-
+// $Id: TTYAgent.h,v 1.18 1997/12/15 13:00:08 zeller Exp $ -*- C++ -*-
 // An agent interface using ptys (pseudo ttys)
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_TTYAgent_h
 #define _DDD_TTYAgent_h
@@ -36,6 +36,7 @@
 #include "LiterateA.h"
 #include <unistd.h>
 #include <stdlib.h>
+#include <fcntl.h>		// O_RDWR
 
 const unsigned TTYAgent_NTypes = LiterateAgent_NTypes;
 
@@ -54,16 +55,21 @@ private:
     void open_slave();	  // open slave tty 
 
 protected:
-    // hooks for alternative communication schemes
+    // Hooks for alternative communication schemes
     virtual int setupCommunication();
     virtual int setupChildCommunication();
     virtual int setupParentCommunication();
+
+    // Open a tty.
+    // Like open(TTY, FLAGS), but care for EAGAIN and EWOULDBLOCK conditions
+    virtual int open_tty(const char *tty, int flags = O_RDWR);
     
 public:
     // Constructors
     TTYAgent(XtAppContext app_context, string pth,
 	     unsigned nTypes = TTYAgent_NTypes):
         LiterateAgent(app_context, pth, nTypes),
+	_master_tty(), _slave_tty(),
 	master(-1), slave(-1),
 	push(false)
     {}
@@ -72,6 +78,7 @@ public:
 	     FILE *out = stdout, FILE *err = 0, 
 	     unsigned nTypes = TTYAgent_NTypes):
         LiterateAgent(app_context, in, out, err, nTypes),
+	_master_tty(), _slave_tty(),
 	master(-1), slave(-1),
 	push(false)
     {}
@@ -79,6 +86,7 @@ public:
     TTYAgent(XtAppContext app_context, bool dummy,
 	     unsigned nTypes = TTYAgent_NTypes):
         LiterateAgent(app_context, dummy, nTypes),
+	_master_tty(), _slave_tty(),
 	master(-1), slave(-1),
 	push(false)
     {}
