@@ -1,4 +1,4 @@
-// $Id: TagBox.h,v 1.7 1997/04/25 06:37:58 zeller Exp $
+// $Id: TagBox.h,v 1.10 1997/12/15 18:54:12 zeller Exp $
 // Deklaration Klasse TagBox
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_TagBox_h
 #define _DDD_TagBox_h
@@ -53,6 +53,8 @@ private:
     // Default access functions
     static DataLink default_datalink;
 
+    TagBox& operator = (const TagBox&) { assert(0); return *this; }
+
 protected:
     // Draw
     virtual void _draw(Widget w, 
