@@ -1,7 +1,7 @@
-// $Id: TypeInfo.h,v 1.9 1997/04/25 06:38:07 zeller Exp $ -*- C++ -*-
+// $Id: TypeInfo.h,v 1.11 1997/12/15 18:49:49 zeller Exp $ -*- C++ -*-
 // Run-time type information
 
-// Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
+// Copyright (C) 1995-1997 Technische Universitaet Braunschweig, Germany.
 // Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 // 
 // This file is part of the ICE Library.
@@ -33,8 +33,44 @@
 #pragma interface
 #endif
 
+#include "config.h"
+
+#if HAVE_TYPEINFO
+
+#define string stdstring
+#include <typeinfo>
+#undef string
+
+// Public interface.  Defined according to: Stroustrup, the C++
+// Programming Language, 2nd Ed., Section 13.5
+
+// Use ISO C++ run-time type information
+#define static_type_info(T) typeid(T)
+#define ptr_type_info(p)    typeid(p)
+#define ref_type_info(r)    typeid(&(r))
+#define ptr_cast(T, p)      dynamic_cast<T *>(p)
+#define ref_cast(T, r)      dynamic_cast<T &>(r)
+
+// Old-style definition macros are no more required
+#define DECLARE_TYPE_INFO
+#define DEFINE_TYPE_INFO_0(T)
+#define DEFINE_TYPE_INFO_1(T, B1)
+#define DEFINE_TYPE_INFO_2(T, B1, B2)
+#define DEFINE_TYPE_INFO_3(T, B1, B2, B3)
+#define DEFINE_TYPE_INFO_4(T, B1, B2, B3, B4)
+#define DEFINE_TYPE_INFO_5(T, B1, B2, B3, B4, B5)
+#define DEFINE_TYPE_INFO_6(T, B1, B2, B3, B4, B5, B6)
+#define DEFINE_TYPE_INFO_7(T, B1, B2, B3, B4, B5, B6, B7)
+#define DEFINE_TYPE_INFO_8(T, B1, B2, B3, B4, B5, B6, B7, B8)
+#define DEFINE_TYPE_INFO_9(T, B1, B2, B3, B4, B5, B6, B7, B8, B9)
+
+#else // !HAVE_TYPEINFO
+
+// No C++ run-time type information available - realize it manually
+
 #include <iostream.h>
 #include <stdlib.h>
+#include "assert.h"
 
 #ifdef __GNUC__
 // Set this to 1 to enable TypeInfo table construction at link time
@@ -129,10 +165,10 @@ class TypeInfo {
 
 private:
     // Data
-    char *_name;              // Name of this class
-    BaseList _direct_bases;   // List of direct base classes
-    BaseList *_all_bases;     // Ptr to list of all base classes
-    unsigned int _hash;	      // Hash code (0 if not yet built)
+    char *_name;		// Name of this class
+    BaseList _direct_bases;	// List of direct base classes
+    BaseList *_all_bases;	// Ptr to list of all base classes
+    unsigned int _hash;		// 1Hash code (0 if not yet built)
 
     void _setup_all_bases() const;
     void setup_all_bases() const
@@ -163,6 +199,12 @@ protected:
     // Make hash code
     void makehash();
 
+private:
+    // No X(const X&)
+    TypeInfo(const TypeInfo&): 
+	_name(0), _direct_bases(0), _all_bases(0), _hash(0) { assert(0); }
+    TypeInfo& operator = (const TypeInfo&) { assert(0); return *this; }
+
 public:
 #if !IMMEDIATE_TYPE_INFO
     // Construction
@@ -173,7 +215,7 @@ public:
 #endif
      
     // Debugging
-    // We cannot use a bool here, since it may be initialized to late
+    // We cannot use a bool here, since it may be initialized too late
     static int debug;
 
     // Resources
@@ -215,6 +257,11 @@ private:
     int index;
     const BaseList bases;
 
+    BaseIterator(const BaseIterator&) : index(0), bases(0) 
+	{ assert(0); }
+    BaseIterator& operator = (const BaseIterator&) 
+	{ assert(0); return *this; }
+
 public:
     enum mode { all, direct };
 
@@ -236,5 +283,7 @@ public:
     {}
 };
 
+#endif // !HAVE_TYPEINFO
+
 #endif // _ICE_TypeInfo_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
