@@ -1,4 +1,4 @@
-// $Id: VSLDef.h,v 1.7 1997/04/25 06:38:15 zeller Exp $
+// $Id: VSLDef.h,v 1.10 1997/12/15 18:54:15 zeller Exp $
 // Deklaration Klasse VSLDef
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_VSLDef_h
 #define _DDD_VSLDef_h
@@ -40,6 +40,7 @@
 #include "bool.h"
 #include "VSLNode.h"
 #include "TypeInfo.h"
+#include "assert.h"
 
 class Box;
 class VSLDefList;
@@ -72,8 +73,8 @@ public:
 
     // Erzeugen
     VSLDef(VSLDefList* l, VSLNode *pattern, VSLNode *e = 0,
-	string filename = "builtin", int lineno = 0):
-	_expr(e),
+	string filename = "builtin", int lineno = 0)
+	: _expr(e),
 	_node_pattern(pattern),
 	_box_pattern(0),
 	_nargs(pattern->nargs()),
@@ -85,6 +86,25 @@ public:
 	deflist(l)
     {}
 
+private:
+    VSLDef(const VSLDef&)
+	:_expr(0),
+	_node_pattern(0),
+	_box_pattern(0),
+	_nargs(0),
+	_straight(0),
+	_filename(),
+	_lineno(0),
+	_listnext(0), _libnext(0), _libprev(0),
+	being_compiled(false),
+	deflist(0)
+    {
+	assert(0);
+    }
+
+    VSLDef& operator = (const VSLDef&) { assert(0); return *this; }
+
+public:
     // Ressourcen
     VSLNode*& expr()            { return _expr; }
     VSLNode*& node_pattern()    { return _node_pattern; }
