@@ -1,4 +1,4 @@
-// $Id: VSLDefList.h,v 1.7 1997/04/25 06:38:17 zeller Exp $
+// $Id: VSLDefList.h,v 1.10 1997/12/15 18:54:16 zeller Exp $
 // Deklaration Klasse VSLDefList
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_VSLDefList_h
 #define _DDD_VSLDefList_h
@@ -67,12 +67,28 @@ public:
 
     // Erzeugen
     VSLDefList(VSLLib* l, unsigned hash, 
-	string func_nm, bool g = false):
-	_func_name(func_nm), _first(0), _last(0), _ndefs(0),
+	string func_nm, bool g = false)
+	: _func_name(func_nm), _first(0), _last(0), _ndefs(0),
 	_next(0), _global(g), lib(l), hashcode(hash), 
 	references(0), self_references(-1)
     {}
 
+
+private:
+    VSLDefList(const VSLDefList&)
+	: _func_name(), _first(0), _last(0), _ndefs(0),
+	_next(0), _global(false), lib(0), hashcode(0), 
+	references(0), self_references(0)
+    {
+	assert(0);
+    }
+
+    VSLDefList& operator = (const VSLDefList&) 
+    { 
+	assert(0); return *this; 
+    }
+
+public:
     // Hinzufuegen
     VSLDef *add(bool& newFlag,
 	VSLNode *pattern, VSLNode *expr = 0,
