@@ -1,4 +1,4 @@
-// $Id: VSLLib.h,v 1.8 1997/04/25 06:38:21 zeller Exp $ 
+// $Id: VSLLib.h,v 1.11 1997/12/15 18:54:17 zeller Exp $ 
 // The VSL Library
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_VSLLib_h
 #define _DDD_VSLLib_h
@@ -98,7 +98,7 @@ public:
     }
 
     // Assignment: just the same.
-    void operator = (Box *box)
+    VSLArg& operator = (Box *box)
     {
 	if (box != _box)
 	{
@@ -106,9 +106,10 @@ public:
 		_box->unlink();
 	    _box = box;
 	}
+	return *this;
     }
 
-    void operator = (const VSLArg& arg)
+    VSLArg& operator = (const VSLArg& arg)
     {
 	if (arg.box() != _box)
 	{
@@ -117,6 +118,7 @@ public:
 
 	    _box = arg.box() ? arg.box()->link() : 0;
 	}
+	return *this;
     }
 };
 
@@ -250,6 +252,9 @@ private:
     // The parse function generated by YACC -- this cannot be a C++ name
     friend int VSLLib_parse();
 
+    VSLLib(const VSLLib&): _lib_name(), _first(0), _last(0) { assert(0); }
+    VSLLib& operator = (const VSLLib&)   { assert(0); return *this; }
+
 public:
     // Build
     VSLLib();
