@@ -1,4 +1,4 @@
-// $Id: VSLNode.h,v 1.8 1997/04/25 06:38:23 zeller Exp $
+// $Id: VSLNode.h,v 1.11 1997/12/15 18:54:18 zeller Exp $
 // Deklaration Klasse VSLNode
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_VSLNode_h
 #define _DDD_VSLNode_h
@@ -83,6 +83,8 @@ protected:
     {
 	return strcmp(_type, node._type) == 0;
     }
+private:
+    VSLNode& operator = (const VSLNode &) { assert(0); return *this; }
 
 public:
     // Knoten erzeugen
