@@ -1,4 +1,4 @@
-// $Id: VarArray.h,v 1.6 1997/04/25 06:38:25 zeller Exp $
+// $Id: VarArray.h,v 1.7 1997/11/12 10:52:30 zeller Exp $
 // Variable-sized array
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -92,6 +92,11 @@ public:
         DynArray<T>(m), _size(m.size())
     {}
 
+    // Destructor.
+    // Omitting this one triggers an internal compiler error in GCC 2.7.2 -O2
+    virtual ~VarArray()
+    {}
+
     // Assignment
     VarArray<T>& operator = (const VarArray<T>& m)
     { 
