@@ -1,4 +1,4 @@
-// $Id: acconfig.h.in,v 1.16 1997/05/22 01:00:50 zeller Exp $ -*- C++ -*-
+// $Id: acconfig.h.in,v 1.29 1998/01/28 14:17:56 zeller Exp $ -*- C++ -*-
 // General configuration file.
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -42,14 +42,26 @@
 #undef HAVE_ARRAY_OPERATOR_NEW
 
 /* Define if you have the X Athena widgets. */
-#undef HAVE_ATHENA_WIDGETS
+#undef HAVE_ATHENA
 
 /* Define if your C++ compiler supports bool types. */
 #undef HAVE_BOOL
 
+/* Define if your C++ compiler supports exception handling. */
+#undef HAVE_EXCEPTIONS
+
+/* Define if your C++ compiler supports ISO C++ standard exceptions. */
+#undef HAVE_STD_EXCEPTIONS
+
+/* Define if your C++ compiler supports run-time type information. */
+#undef HAVE_TYPEINFO
+
 /* Define if <sys/core.h> defines CORE_MAGIC to identify core files. */
 #undef HAVE_CORE_MAGIC
 
+/* Define if ptrace() supports a PTRACE_DUMPCORE request to dump core files. */
+#undef HAVE_PTRACE_DUMPCORE
+
 /* Define if your C++ library has an ostrstream::frozen() function. */
 #undef HAVE_FROZEN_OSTRSTREAM
 
@@ -59,11 +71,15 @@
 /* Define if MAXPATHLEN is defined or declared in <sys/param.h>. */
 #undef HAVE_MAXPATHLEN
 
-/* Define if you have XPM widgets. */
-#undef HAVE_XPM_WIDGETS
+/* Define if you have the XP library (X11R6.3 print server).
+   Required by Motif 2.1 and later. */
+#undef HAVE_XP
+
+/* Define if you have the XPM library. */
+#undef HAVE_XPM
 
 /* Define if you have Motif widgets. */
-#undef HAVE_MOTIF_WIDGETS
+#undef HAVE_MOTIF
 
 /* Define if your Motif widgets are actually LessTif widgets. */
 #undef HAVE_LESSTIF
@@ -89,10 +105,6 @@
 /* Define if the regex_t type has a re_nsub member, according to POSIX.2 */
 #undef HAVE_REGEX_T_RE_NSUB
 
-/* Define to enable some LessTif bug workarounds.  Required for
-   LessTif 0.79, for instance.  Don't use these with Motif. */
-#undef LESSTIF_HACKS
-
 /* Define to the signal handler type accepted by signal(). 
    See the signal man page and the decl in <signal.h> for the exact type.
    Typically values are int, ..., and int .... */
@@ -101,15 +113,24 @@
 /* Define if regcomp() from <regex.h> does not work. */
 #undef REGCOMP_BROKEN
 
-/* Define if you want ICE to use X Athena widgets. */
-#undef WITH_ATHENA_WIDGETS
+/* Define if you want this program to use X Athena widgets. */
+#undef WITH_ATHENA
 
 /* Define if you want to replace the ICE built-in 'test' command by
    the external test program. */
 #undef WITH_EXTERNAL_TEST
 
-/* Define if you want ICE to use Motif widgets. */
-#undef WITH_MOTIF_WIDGETS
+/* Define if you want this program to use Motif widgets. */
+#undef WITH_MOTIF
+
+/* Define if you want support for runtime-compiled regexps.  Required
+   in ICE; not needed in DDD.  */
+#undef WITH_RUNTIME_REGEX
+
+/* Define if you want regexps to be compiled at runtime.  Default in
+   DDD 2.1 and earlier.  Requires ~30% more memory; slightly slower,
+   too.  Requires WITH_RUNTIME_REGEX to be set.  Required in ICE.  */
+#undef RUNTIME_REGEX
 
 
 // @BOTTOM@
@@ -141,6 +162,12 @@
 /* Define if getrusage is declared in sys/resource.h. */
 #undef HAVE_GETRUSAGE_DECL
 
+/* Define if getrlimit is declared in sys/resource.h. */
+#undef HAVE_GETRLIMIT_DECL
+
+/* Define if setrlimit is declared in sys/resource.h. */
+#undef HAVE_SETRLIMIT_DECL
+
 /* Define if getwd is declared in unistd.h. */
 #undef HAVE_GETWD_DECL
 
@@ -153,9 +180,15 @@
 /* Define if grantpt is declared in stdlib.h. */
 #undef HAVE_GRANTPT_DECL
 
+/* Define if hypot is declared in math.h. */
+#undef HAVE_HYPOT_DECL
+
 /* Define if ioctl is declared in unistd.h. */
 #undef HAVE_IOCTL_DECL
 
+/* Define if link is declared in unistd.h. */
+#undef HAVE_LINK_DECL
+
 /* Define if lstat is declared in sys/stat.h. */
 #undef HAVE_LSTAT_DECL
 
@@ -174,6 +207,9 @@
 /* Define if pclose is declared in stdio.h. */
 #undef HAVE_PCLOSE_DECL
 
+/* Define if ptrace is declared in unistd.h sys/ptrace.h. */
+#undef HAVE_PTRACE_DECL
+
 /* Define if ptsname is declared in stdlib.h. */
 #undef HAVE_PTSNAME_DECL
 
@@ -246,6 +282,9 @@
 /* Define if strtod is declared in stdlib.h. */
 #undef HAVE_STRTOD_DECL
 
+/* Define if symlink is declared in unistd.h. */
+#undef HAVE_SYMLINK_DECL
+
 /* Define if tcgetattr is declared in termios.h. */
 #undef HAVE_TCGETATTR_DECL
 
