@@ -7,17 +7,22 @@ ICE_CHECK_DECL(ftime, sys/timeb.h)
 ICE_CHECK_DECL(gethostname, unistd.h)
 ICE_CHECK_DECL(gethostbyname, netdb.h)
 ICE_CHECK_DECL(getrusage, sys/resource.h)
+ICE_CHECK_DECL(getrlimit, sys/resource.h)
+ICE_CHECK_DECL(setrlimit, sys/resource.h)
 ICE_CHECK_DECL(getwd, unistd.h)
 ICE_CHECK_DECL(getpty, unistd.h)
 ICE_CHECK_DECL(_getpty, unistd.h)
 ICE_CHECK_DECL(grantpt, stdlib.h)
+ICE_CHECK_DECL(hypot, math.h)
 ICE_CHECK_DECL(ioctl, unistd.h)
+ICE_CHECK_DECL(link, unistd.h)
 ICE_CHECK_DECL(lstat, sys/stat.h)
 ICE_CHECK_DECL(malloc, stdlib.h)
 ICE_CHECK_DECL(memcpy, string.h)
 ICE_CHECK_DECL(memset, string.h)
 ICE_CHECK_DECL(popen, stdio.h)
 ICE_CHECK_DECL(pclose, stdio.h)
+ICE_CHECK_DECL(ptrace, unistd.h sys/ptrace.h)
 ICE_CHECK_DECL(ptsname, stdlib.h)
 ICE_CHECK_DECL(raise, signal.h)
 ICE_CHECK_DECL(rand, stdlib.h)
@@ -42,6 +47,7 @@ ICE_CHECK_DECL(strftime, time.h)
 ICE_CHECK_DECL(strsignal, string.h)
 ICE_CHECK_DECL(strtol, stdlib.h)
 ICE_CHECK_DECL(strtod, stdlib.h)
+ICE_CHECK_DECL(symlink, unistd.h)
 ICE_CHECK_DECL(tcgetattr, termios.h)
 ICE_CHECK_DECL(tcsetattr, termios.h)
 ICE_CHECK_DECL(tcgetsid, sys/termios.h)
