@@ -1,4 +1,4 @@
-// $Id: bool.h,v 1.6 1997/04/25 06:38:35 zeller Exp $ -*- C++ -*-
+// $Id: bool.h,v 1.8 1998/01/27 09:46:33 zeller Exp $ -*- C++ -*-
 // `bool' type
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,14 +24,14 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_bool_h
 #define _DDD_bool_h
 
 #include "config.h"
 
-#ifndef HAVE_BOOL
+#if !HAVE_BOOL
 
 // Simple replacement for ANSI C++ `bool' type
 typedef int bool;
