@@ -1,4 +1,4 @@
-// $Id: comm-manag.h,v 1.8 1997/04/25 06:38:45 zeller Exp $
+// $Id: comm-manag.h,v 1.14 1997/10/08 08:43:28 zeller Exp $
 // GDB communication manager.
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,14 +24,14 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
+
 
 //-----------------------------------------------------------------------------
-// Kommunikation mit dem gdb.
-// Namenskonventionen: 
-// ...SUC : ruft send_user_cmd() des gdb auf.
-// ...OA  : fuer on_answer, Typ: OAProc, siehe gdbAgent.
-// ...OAC : fuer on_answer_completion, Typ: OACProc, siehe gdbAgent.
+// GDB communication manager
+// Name conventions:
+// ...OA  : an OAProc used in GDBAgent::on_answer
+// ...OAC : an OACProc used in GDBAgent::on_answer_completion()
 //-----------------------------------------------------------------------------
 
 #ifndef _DDD_comm_manag_h
@@ -43,34 +43,29 @@
 
 #include "GDBAgent.h"
 
+// Note: `Command.h' is the preferred way of interacting with GDB.
 
-//-----------------------------------------------------------------------------
-// Deklarationen
-//-----------------------------------------------------------------------------
-
-//-----------------------------------------------------------------------------
-// Ruft gdb->start mit den noetigen Parametern.
-//
+// Call gdb->start() with required parameters
 void start_gdb ();
 
-//-----------------------------------------------------------------------------
-// Behandlung der Benutzer-Befehle (am Prompt oder mit Knopf eingegeben)
-// Schickt den Benutzter-Befehl cmd an den gdb.
-// Setzt Filtering , ruft ggf. handle_graph_cmd, setzt insensitiv und delay,
-// schreibt Befehlstext ins gdb_w und schickt Befehl an gdb.
-//
-void user_cmdSUC (string cmd, Widget origin = 0,
-		  OQCProc callback = 0, void *data = 0);
+// Send user command CMD to GDB.  Invoke CALLBACK with DATA upon
+// completion.  If VERBOSE is set, issue command in GDB console.
+// If CHECK is set, add appropriate GDB commands to get GDB state.
+void send_gdb_command(string cmd, Widget origin,
+		      OQCProc callback, void *data,
+		      bool verbose, bool check);
 
-
-// ***************************************************************************
-// Behandlung von Benutzer-Eingaben
-// Schickt die Benutzer-Eingabe CMD unveraendert an den gdb.
-//
-void user_rawSUC (string cmd, Widget origin = 0);
+// Send user input CMD to GDB (unchanged).
+void send_gdb_ctrl(string cmd, Widget origin = 0);
 
 // Return FALSE if ANSWER is an error message indicating an unknown command
 bool is_known_command(const string& answer);
 
+// Replace all occurrences of `@N@' by N + the current breakpoint base.
+void fix_bp_numbers(string& cmd);
+
+// Send commands to initialize a session
+void init_session(const string& restart, const string& settings);
+
 #endif // _DDD_comm_manag_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
