@@ -1,4 +1,4 @@
-// $Id: converters.h,v 1.7 1997/04/25 06:38:56 zeller Exp $
+// $Id: converters.h,v 1.9 1997/10/03 10:40:14 zeller Exp $
 // Own converters
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,11 +24,13 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_converters_h
 #define _DDD_converters_h
 
+#include <X11/Intrinsic.h>
+
 // Convert String to Widget
 extern Boolean CvtStringToWidget(Display *display, 
 				 XrmValue *args, Cardinal *num_args, 
@@ -71,6 +73,12 @@ extern Boolean CvtStringToPacking(Display *display,
 				  XrmValue *fromVal, XrmValue *toVal,
 				  XtPointer *converter_data);
 
+// Convert String to OnOff
+Boolean CvtStringToOnOff(Display *display, 
+			 XrmValue *args, Cardinal *num_args, 
+			 XrmValue *fromVal, XrmValue *toVal,
+			 XtPointer *converter_data);
+
 // Register all converters
 extern void registerOwnConverters();
 
