@@ -1,4 +1,4 @@
-// $Id: ddd.h,v 1.23 1997/04/25 06:39:14 zeller Exp $
+// $Id: ddd.h,v 1.30 1998/01/27 14:26:58 zeller Exp $
 // DDD application resources
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_ddd_h
 #define _DDD_ddd_h
@@ -34,7 +34,7 @@
 #endif
 
 #include "strclass.h"
-#include <setjmp.h>
+#include <fstream.h>
 
 #include <X11/Intrinsic.h>
 #include <Xm/Xm.h>
@@ -56,6 +56,15 @@ extern void _gdb_out(string text);
 // Update option menus
 extern void update_options();
 
+// Update `Reset' button in preferences panel
+extern void update_reset_preferences();
+
+// Update argument buttons
+extern void update_arg_buttons();
+
+// Update user-defined buttons
+extern void update_user_buttons();
+
 // Save current option state
 extern void save_option_state();
 
@@ -71,12 +80,6 @@ extern bool private_gdb_output;
 // True if input is running
 extern bool private_gdb_input;
 
-// True if we have reached the main event loop
-extern bool main_loop_entered;
-
-// Longjmp environment to return to main event loop
-extern jmp_buf main_loop_env;
-
 // True if GDB issued initial prompt
 extern bool gdb_initialized;
 
@@ -86,15 +89,17 @@ extern class DataDisp   *data_disp;
 extern class SourceView *source_view;
 extern class ArgField   *source_arg;
 
+// Where to log DDD I/O
+extern ofstream dddlog;
+
 // Text to ignore upon output
 extern string gdb_out_ignore;
 
-// Pass the COMMAND given in CLIENT_DATA to gdb_command()
-void gdbCommandCB(Widget w, XtPointer call_data, XtPointer client_data);
-
 // Process next DDD event
 void process_next_event();
 
+// Setup is done
+Boolean ddd_setup_done(XtPointer client_data);
+
 #endif // _DDD_ddd_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
-
