@@ -1,4 +1,4 @@
-// $Id: disp-read.h,v 1.15 1997/04/25 06:39:22 zeller Exp $
+// $Id: disp-read.h,v 1.21 1997/10/30 08:08:46 zeller Exp $
 // Helper functions to process GDB display output
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 //-----------------------------------------------------------------------------
 // Verschiedene Routinen, die das Erkennen bzw. Lesen
@@ -74,6 +74,9 @@ bool is_enable_display_cmd(const string& cmd);
 // True if CMD executes debuggee and shows new displays
 bool is_running_cmd(const string& cmd, GDBAgent *gdb);
 
+// True if CMD changes current execution position
+bool is_pc_cmd(const string& cmd);
+
 // True if CMD starts debuggee
 bool is_run_cmd(const string& cmd);
 
@@ -85,11 +88,14 @@ bool is_frame_cmd(const string& cmd);
 bool is_up_cmd(const string& cmd);   // ... towards caller
 bool is_down_cmd(const string& cmd); // ... towards called
 
+// True if CMD resets process memory.
+bool is_core_cmd(const string& cmd);
+
 // True if CMD changes the current thread
 bool is_thread_cmd(const string& cmd);
 
 // True if CMD changes variable values.
-bool is_set_cmd(const string& cmd);
+bool is_set_cmd(const string& cmd, GDBAgent *gdb);
 
 // True if CMD changes debugger settings.
 bool is_setting_cmd(const string& cmd);
@@ -118,6 +124,9 @@ bool is_refresh_cmd(const string& cmd);
 // Return the string after a `display' command.
 string get_display_expression(const string& cmd);
 
+// Return the string after a `break' command
+string get_break_expression(const string& cmd);
+
 
 //----------------------------------------------------------------------------
 // Handle `display' output
@@ -136,7 +145,7 @@ int possible_begin_of_display (string gdb_answer, GDBAgent *gdb);
 string read_next_display (string& displays, GDBAgent *gdb);
 
 // Remove and return "NR: NAME = " from DISPLAY.
-string get_disp_value_str (/*const*/ string& display, GDBAgent *gdb);
+string get_disp_value_str (const string& display, GDBAgent *gdb);
 
 
 //----------------------------------------------------------------------------
@@ -171,5 +180,14 @@ bool is_disabling (const string& value, GDBAgent *gdb);
 // True if VALUE is an invalid value (i.e., an error message)
 bool is_invalid(const string& value);
 
+
+
+//-----------------------------------------------------------------------------
+// Handle `where' output
+//-----------------------------------------------------------------------------
+
+// Fetch current scope from GDB `where' output (a function name)
+string get_scope(const string& where_output);
+
 #endif // _DDD_disp_read_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
