@@ -1,4 +1,4 @@
-// $Id: hash.h,v 1.4 1997/04/25 06:39:50 zeller Exp $ -*- C++ -*-
+// $Id: hash.h,v 1.5 1997/12/15 13:00:39 zeller Exp $ -*- C++ -*-
 // Hash functions
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -36,7 +36,7 @@ unsigned int hashpjw(const char*);
 inline unsigned int multiplicativehash(int x)
 {
     // uses a const close to golden ratio * pow(2,32)
-    return ((unsigned)x) * 2654435767;
+    return ((unsigned)x) * 2654435767UL;
 }
 
 unsigned int foldhash(double);
