@@ -1,4 +1,4 @@
-// $Id: history.h,v 1.5 1997/04/25 06:39:53 zeller Exp $ -*- C++ -*-
+// $Id: history.h,v 1.8 1997/10/03 10:40:52 zeller Exp $ -*- C++ -*-
 // DDD command history
 
 // Copyright (C) 1996 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_history_h
 #define _DDD_history_h
@@ -40,16 +40,21 @@
 
 
 // History management
-extern void init_history_file();
 extern void process_history_filename(string answer);
 extern void process_history_size(string answer);
-extern void process_history_save(string answer);
 extern void add_to_history(const string& line);
 extern void set_history_from_line(const string& line, 
 				  bool ignore_history_commands = false);
-extern void load_history();
-extern void save_history(Widget origin = 0);
 
+// Set and get GDB history file
+extern void set_gdb_history_file(const string& file);
+extern string gdb_history_file();
+
+// Load history from FILE
+extern void load_history(const string& file);
+
+// Save history into FILE
+extern void save_history(const string& file, Widget origin = 0);
 
 // Last command from history
 extern string last_command_from_history();
