@@ -1,4 +1,4 @@
-// $Id: post.h,v 1.4 1997/04/25 06:40:19 zeller Exp $ -*- C++ -*-
+// $Id: post.h,v 1.7 1997/10/03 10:41:13 zeller Exp $ -*- C++ -*-
 //
 
 // Copyright (C) 1996 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_post_h
 #define _DDD_post_h
@@ -38,19 +38,21 @@
 
 // Error handling
 
-// In the following functions, ORIGIN indicates some widget
-// which originated the command.  Any subsequent dialogs
-// are positioned next to ORIGIN.  If ORIGIN is omitted,
-// the widget executing the last command is used.
-extern void post_gdb_busy(Widget origin = 0);
-extern void post_gdb_message(string text, Widget origin = 0);
-extern void post_gdb_yn(string text, Widget origin = 0);
-extern void post_gdb_died(string reason, int gdb_status, Widget origin = 0);
-extern void post_error(string text, String name = 0, Widget origin = 0);
-extern void post_warning(string text, String name = 0, Widget origin = 0);
+// In the following functions, ORIGIN indicates some widget which
+// originated the command.  Any subsequent dialogs are positioned next
+// to ORIGIN.  If ORIGIN is omitted, the widget executing the last
+// command is used.  Each function returns the created, managed, and
+// raised widget, or 0 if no widget was shown.
+extern Widget post_gdb_busy(Widget origin = 0);
+extern Widget post_gdb_message(string text, Widget origin = 0);
+extern Widget post_gdb_yn(string text, Widget origin = 0);
+extern Widget post_gdb_died(string reason, int gdb_status, Widget origin = 0);
+extern Widget post_error(string text, String name = 0, Widget origin = 0);
+extern Widget post_warning(string text, String name = 0, Widget origin = 0);
 
-// General yes/no widget
-extern Widget yn_dialog;
+// Unpost specific messages
+extern void unpost_gdb_busy();
+extern void unpost_gdb_yn();
 
 // Issue CLIENT_DATA as command and unmanage YN_DIALOG.
 void YnCB(Widget dialog, XtPointer client_data, XtPointer call_data);
