@@ -1,4 +1,4 @@
-// $Id: show.h,v 1.8 1997/04/25 06:40:45 zeller Exp $ -*- C++ -*-
+// $Id: show.h,v 1.12 1998/01/20 14:59:36 zeller Exp $ -*- C++ -*-
 // DDD info functions
 
 // Copyright (C) 1996 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_show_h
 #define _DDD_show_h
@@ -40,23 +40,26 @@
 #include <iostream.h>
 
 // Help texts
-void show_invocation(DebuggerType type);
-void show_version();
-void show_configuration();
-void show_manual();
-void show_license();
+void show_invocation(DebuggerType type, ostream& os);
+void show_version(ostream& os);
+void show_configuration(ostream& os);
+void show(int (*formatter)(ostream& os));
 
 // WWW page
 void DDDWWWPageCB(Widget, XtPointer, XtPointer);
 
 // Manual
-void ddd_man(ostream& os);
+int ddd_man(ostream& os);
 void DDDManualCB(Widget, XtPointer, XtPointer);
 void GDBManualCB(Widget, XtPointer, XtPointer);
 
 // License
-void ddd_license(ostream& os);
+int ddd_license(ostream& os);
 void DDDLicenseCB(Widget, XtPointer, XtPointer);
 
+// News
+int ddd_news(ostream& os);
+void DDDNewsCB(Widget, XtPointer, XtPointer);
+
 #endif // _DDD_show_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
