@@ -1,4 +1,4 @@
-// $Id: status.h,v 1.10 1997/04/25 06:40:51 zeller Exp $ -*- C++ -*-
+// $Id: status.h,v 1.17 1997/10/08 13:16:44 zeller Exp $ -*- C++ -*-
 // Interpret GDB output
 
 // Copyright (C) 1996 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_status_h
 #define _DDD_status_h
@@ -40,10 +40,11 @@
 #include <X11/Intrinsic.h>
 
 // Show MESSAGE in status window.
-void set_status(string message);
+// If TEMPORARY is set, override locks and do not add to status history.
+void set_status(string message, bool temporary = false);
 
 // Same, but use an MString.
-void set_status_mstring(MString text);
+void set_status_mstring(MString text, bool temporary = false);
 
 // Return current contents of status line
 extern const MString& current_status();
@@ -58,29 +59,59 @@ void set_status_from_gdb(const string& text);
  // True if last cmd came from GDB window
 extern bool gdb_keyboard_command;
 
+// True if asking `yes or no'
+extern bool gdb_asks_yn;
+
 // True if the next line is to be displayed in the status line
 extern bool show_next_line_in_status;
 
 // Number of messages to keep in status history
 extern int status_history_size;
 
-// This is convenient for setting the status during a function
-class StatusDelay: public Delay {
+// Status lock
+void lock_status();		// Place a lock on status
+void unlock_status();		// Remove lock from status
+void reset_status_lock();	// Remove all locks from status
+
+// These are convenient for setting the status during a function
+class _StatusMsg {
 private:
     string cause;
 
 public:
-    StatusDelay(const string& c)
-	: cause(c)
+    string outcome;
+
+    _StatusMsg(const string& c)
+	: cause(c), outcome("done")
     {
 	set_status(cause + "...");
     }
 
-    ~StatusDelay()
+    virtual ~_StatusMsg()
     {
-	set_status(cause + "...done.");
+	set_status(cause + "..." + outcome + ".");
     }
 };
 
+class StatusMsg: public _StatusMsg {
+public:
+    StatusMsg(const string& c)
+	: _StatusMsg(c)
+    {
+	lock_status();
+    }
+    virtual ~StatusMsg()
+    {
+	unlock_status();
+    }
+};
+
+class StatusDelay: public StatusMsg, public Delay {
+public:
+    StatusDelay(const string& c)
+	: StatusMsg(c)
+    {}
+};
+
 #endif // _DDD_status_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
