@@ -1,4 +1,4 @@
-// $Id: string-fun.h,v 1.7 1997/04/25 06:40:52 zeller Exp $
+// $Id: string-fun.h,v 1.11 1997/10/03 10:41:46 zeller Exp $
 // Miscellaneous string functions
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 //-----------------------------------------------------------------------------
 // Verschiedene Funktionen auf string
@@ -42,37 +42,31 @@
 
 //-----------------------------------------------------------------------------
 
-extern regex RXblanks;
-extern regex RXblanks_or_tabs;
+#if RUNTIME_REGEX
+extern const regex rxblanks;
+extern const regex rxblanks_or_tabs;
+#endif
 
-
-// ***************************************************************************
+// Convert NR to a string
 string itostring (int nr);
 
-// ***************************************************************************
+// Return true iff S begins with an integer
 bool has_nr (const string& s);
 
-// ***************************************************************************
-// gibt den Integer zurueck, der am Anfang des String steht
-// 
-int get_nr (/*const*/ string& s);
+// Return the integer at beginning of S, or 0 if none
+int get_nr (const string& s);
 
-// ***************************************************************************
+// Return the integer at beginning of S, or -1 if none
 int get_positive_nr (const char* s);
+int get_positive_nr (const string& s);
 
-// ***************************************************************************
-int get_positive_nr (/*const*/ string& s);
-
-// ***************************************************************************
+// Remove leading blanks from S
 void read_leading_blanks (string& value);
 
-// ***************************************************************************
-// gibt den Nummer-String zurueck, der am Anfang des String steht und
-// loescht diesen aus dem uebergebenen String.
-// 
+// Remove and return a leading integer from S, or "" if none
 string read_nr_str (string& s);
 
-// ***************************************************************************
+// Remove and return a leading integer from S, or 0 if none
 int read_positive_nr (string& s);
 
 // Strip final characters
