@@ -1,4 +1,4 @@
-// $Id: windows.h,v 1.12 1997/04/29 23:52:39 zeller Exp $ -*- C++ -*-
+// $Id: windows.h,v 1.18 1997/11/15 21:22:38 zeller Exp $ -*- C++ -*-
 //
 
 // Copyright (C) 1996 Technische Universitaet Braunschweig, Germany.
@@ -24,7 +24,7 @@
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
 // `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
+// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
 
 #ifndef _DDD_windows_h
 #define _DDD_windows_h
@@ -50,8 +50,10 @@ extern bool popups_disabled;
 
 // Shell management
 extern void initial_popup_shell(Widget w);
+extern void popup_shell(Widget w);
 extern void popdown_shell(Widget w);
 extern void iconify_shell(Widget w);
+extern void uniconify_shell(Widget w);
 extern int running_shells();
 
 extern void gdbOpenCommandWindowCB  (Widget, XtPointer, XtPointer);
@@ -84,6 +86,8 @@ extern bool have_visible_data_window();
 extern bool have_visible_exec_window();
 extern bool have_visible_tool_window();
 
+
+// Close current window
 extern void DDDCloseCB              (Widget, XtPointer, XtPointer);
 
 // Register this event handler with all shells
